package PAR::StrippedPARL::Dynamic;
use 5.006;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See L<http://www.perl.com/perl/misc/Artistic.html>

=cut


__DATA__
M?T5,1@$!`0````````````(``P`!````4)H$"#0```!TLP```````#0`(``(
M`"@`&P`:``8````T````-(`$"#2`!`@``0````$```4````$`````P```#0!
M```T@00(-($$"!,````3````!`````$````!``````````"`!`@`@`0(3*\`
M`$RO```%`````!````$`````L````#`%"``P!0B(`@```!,```8`````$```
M`@```!2P```4,`4(%#`%"`@!```(`0``!@````0````$````2`$``$B!!`A(
M@00((````"`````$````!````%#E=&3$J0``Q"D%",0I!0C4````U`````0`
M```$````4>5T9```````````````````````````!@````0````O;&EB+VQD
M+6QI;G5X+G-O+C(```0````0`````0```$=.50```````@````8````)````
M)0```%$````(````"``````0$`0E0`2"J`$``:*&`:A````"3R@$*3BB,D>*
MA`P(40```%,```````````````````!5````5P```%@```!9````6@```%L`
M``!<````70```%\```!@`````````&$```````````````````!B````90``
M````````````9@```&@```!I````:P````````!M````;P``````````````
M<0```'(```!T`````````,C5LG%9Z.WLSMY'+:/@^TGJT^\.I]VC:R_%F[;;
MS>.>Y^]?>X?YG(%K"4/6.?*+'`PZEPM'F`7&Q8D%D`T4XIXA_^0.L@&+;\2Y
MG$!K?YI\?ZF<FV[%WQ_9<5@<N^.2?-1DU'RM2^/`,F+;[>&G`@IFK\QF>_!*
M:^)'Q@%#1=7L?4&.Q<+E/RRA(@L@\MO3'?JA;&"YC?$.````````````````
M`````!H#`````````````!(```"L```````````````2````KP,`````````
M````$@```)H#`````````````!(```"<`0`````````````2````[0,`````
M````````$@```'4"`````````````!(```#8`P`````````````2````#```
M````````````(````!L``````````````"````"@`P`````````````2````
MB`$`````````````$@````X$`````````````!(```!I`0`````````````2
M````>P$`````````````$@```%$$`````````````!(```!1`P``````````
M```2````*P,`````````````$@```"<"`````````````!(```#X````````
M```````2````%P(`````````````$@```,0#`````````````!(```#%`0``
M```````````2````A@0`````````````$@```$0$`````````````!(```#Y
M`@`````````````2````,P,`````````````$@```),"`````````````!(`
M``#E`0`````````````2````H0$`````````````$@```#`"````````````
M`!(```#[`P`````````````2````>`0`````````````$@```"H!````````
M`````!(````&!``````````````2````+P``````````````$@```!@$````
M`````````!(```!8`0`````````````2````PP``````````````$@```%@$
M`````````````!(```#F`P`````````````2````/00`````````````$@``
M`+T#`````````````!(```"3`P`````````````2````>@4`````````````
M$@```#P!`````````````!(````M!``````````````2````5P(`````````
M````$@```'D#`````````````!(````-`P`````````````2````20(`````
M````````$@```,L#`````````````!(```",`@`````````````2````I@$`
M````````````$@```((#`````````````!(```#2`P`````````````2````
MM@,`````````````$@```.<``````````````!(````]```````````````2
M````-`0`````````````$@```'`$`````````````!(```#2````````````
M```2````^0$`````````````$@```(`"`````````````!(```!+`0``````
M```````2````8@0`````````````$@```*@#`````````````!(```!H`P``
M```````````2````$P,`````````````$@```!@!`````````````!(````^
M`@`````````````2````3P``````````````$@```-,!`````````````!(`
M``!>```````````````2````?P0`````````````$@```(H`````````````
M`!(```!P`P`````````````2````8P,`````````````$@```',`````````
M`````!(````&`0`````````````2````L@$``*25!`@`````$@```!L%``"@
MR@0(!````!$`#@#X!0``L+8$"'`+```2``P`)`8``*"S!`B?`0``$@`,`!4%
M``!\R@0(`````!(`#0":!```P#(%"`0````A`!@`[00``("P!`@+````$@`,
M`*0%``#@R00(6@```!(`#`"Y!0``(,X$"*%;```1``X`FP```(27!`@`````
M$@```(\%``!T,@4(`````!``%P`F!```H#(%"`0````1`!@`D04``'0R!0@`
M````(``7`+0%``"`,@4(!````!$`%P"9!```P#(%"`0````A`!@`"P4``$#*
M!`@%````$@`,`!<&``"0L`0(YP$``!(`#``X!0``0+4$"$(````2``P`F`0`
M`,`R!0@$````$0`8`),$``"`QP0((`(``!(`#`!H!0``D+4$"!X````2``P`
M@P4``*#&!`AS````$@`,`*D$``"(,@4(`````!``\?^U!````$,%"``````0
M`/'_(@4``"#"!`A\!```$@`,`$(#``"DR@0(!````!$`#@"5!0``4)H$"```
M```2``P`1@4``)"O!`CB````$@`,`%P%``"PL@0([````!(`#`!E`@``=)<$
M"``````2````_@0``("R!`@M````$@`,`*($``"(,@4(`````!``\?_(!0``
M(,<$"%L````2``P`G`4``."N!`@]````$@`,`.0%``"$,@4(!````!$`%P">
M`@``Q#(%"!,````1`!@`!08``+"U!`@``0``$@`,`)X%``#DE`0(`````!(`
M"@``;&EB<&5R;"YS;P!?7V=M;VY?<W1A<G1?7P!?2G9?4F5G:7-T97)#;&%S
M<V5S`%!E<FQ?<WES7W1E<FT`4&5R;%])<W1A=&)U9E]P='(`4&5R;%]S>7-?
M:6YI=#,`4&5R;%])97AI=%]F;&%G<U]P='(`4&5R;%]S879E7V1E<W1R=6-T
M;W)?>`!097)L7TEC;VUP8W9?<'1R`%!E<FQ?871F;W)K7VQO8VL`4&5R;%])
M8W5R<W1A8VMI;F9O7W!T<@!P97)L7V-O;G-T<G5C=`!097)L7V-R;V%K7VYO
M8V]N=&5X=`!097)L7TEP87)S97)?<'1R`%!E<FQ?879?<VAI9G0`4&5R;%]S
M=E\R<'9?9FQA9W,`4&5R;%])=&]P7V5N=E]P='(`4&5R;%])=&%I;G1E9%]P
M='(`4&5R;%]S=E]S971P=FX`4&5R;%]N97=35G!V`%!E<FQ?;F5W6%-?9FQA
M9W,`4&5R;%]):6Y?979A;%]P='(`4&5R;%]);W!?<'1R`%!E<FQ?265V86Q?
M<F]O=%]P='(`<&5R;%]F<F5E`%!E<FQ?;6=?<V5T`%!E<FQ?871F;W)K7W5N
M;&]C:P!097)L7W-V7W-E='!V`%!E<FQ?1W1H<E]K97E?<'1R`%!E<FQ?1V1O
M7W5N9'5M<%]P='(`4&5R;%])<&5R;%]D97-T<G5C=%]L979E;%]P='(`4&5R
M;%]G=E]F971C:'!V`'!E<FQ?<G5N`%!E<FQ?9&]U;G=I;F0`4&5R;%]N97=8
M4P!P97)L7V1E<W1R=6-T`%!E<FQ?879?9F5T8V@`8F]O=%]$>6YA3&]A9&5R
M`'!E<FQ?<&%R<V4`4&5R;%]S869E<WES;6%L;&]C`'!E<FQ?86QL;V,`4$Q?
M;65M;W)Y7W=R87``;&EB;G-L+G-O+C$`;&EB9&PN<V\N,@!L:6)M+G-O+C8`
M;&EB8W)Y<'0N<V\N,0!L:6)U=&EL+G-O+C$`;&EB<'1H<F5A9"YS;RXP`'!T
M:')E861?9V5T<W!E8VEF:6,`8VQO<V4`;W!E;C8T`%]?97)R;F]?;&]C871I
M;VX`;'-E96LV-`!R96%D`&QI8F,N<V\N-@!?24]?<W1D:6Y?=7-E9`!?7W)E
M9VES=&5R7V%T9F]R:P!E>&ET`'-T<FYC;7``7U]S=')D=7``8VQO<V5D:7(`
M7U]S=&%C:U]C:&M?9F%I;`!U;FQI;FL`;6MD:7(`<F5A;&QO8P!M96UC:'(`
M9V5T<&ED`'-T<G1O:P!S=')L96X`;65M<V5T`'-T<G-T<@!R;61I<@!?7V9P
M<FEN=&9?8VAK`&UE;6-P>0!?7W-T<FYC<'E?8VAK`%]?;'AS=&%T-C0`;W!E
M;F1I<@!?7WAS=&%T-C0`7U]C='EP95]B7VQO8P!S=&1E<G(`9V5T=6ED`')E
M861L:6YK`&5X96-V<`!?7VUE;6-P>5]C:&L`<W1R8VAR`')E861D:7(V-`!?
M7W-P<FEN=&9?8VAK`&UE;6UO=F4`86-C97-S`'-T<F-M<`!?7VQI8F-?<W1A
M<G1?;6%I;@!?7V5N=FER;VX`7V5D871A`%]?8G-S7W-T87)T`%]E;F0`+W5S
M<B]L:6(O<&5R;#4O-2XQ,BXS+VDS.#8M;&EN=7@M=&AR96%D+6UU;'1I+T-/
M4D4`<&%R7V-U<G)E;G1?97AE8P!P87)?8F%S96YA;64`7U]L:6)C7V-S=5]F
M:6YI`%]F<%]H=P!84U]);G1E<FYA;'-?4$%27T)/3U0`<&%R7V5N=E]C;&5A
M;@!P87)?8W5R<F5N=%]E>&5C7W!R;V,`<&%R7V1I<FYA;64`9V5T7W5S97)N
M86UE7V9R;VU?9V5T<'=U:60`<&%R7V-L96%N=7``7U]D871A7W-T87)T`'AS
M7VEN:70`7U]L:6)C7V-S=5]I;FET`&YA;65?;&]A9%]M>5]P87)?<&P`6%-?
M26YT97)N86QS7U!!4E]#3$5!4E-404-+`'-I>F5?;&]A9%]M>5]P87)?<&P`
M<&%R7VUK=&UP9&ER`'!A<E]S971U<%]L:6)P871H`'!A<E]F:6YD<')O9P!P
M87)?:6YI=%]E;G8`1TQ)0D-?,BXT`$=,24)#7S(N,P!'3$E"0U\R+C,N,@!'
M3$E"0U\R+C(`1TQ)0D-?,BXS+C0`1TQ)0D-?,BXP``````(````#``,````$
M````!````````P````4```````,`!@`'``````````,````#``0``@`"````
M```#````!0`#`````P````@```````4``P`#``,``P`#`````P````,``@``
M``,``P````D``P`#```````#``,````````````$``,``P`'````````````
M```#`````P`#``````````$``0`!``$``P`!``$``0````$``P`!``$``P`!
M``$``0`#``$``0`!``$``0`!``$``0`!``$````!``$``0`!``$````!``$`
M`0`&`#@#```0````<````!1I:0T```D`,08``!`````3:6D-```(`#L&```0
M````<AEI"0``!@!%!@``$````!)I:0T```4`408``!````!T&6D)```$`%L&
M```0````$&EI#0```P!G!@````````$``@#I`@``$``````````2:6D-```'
M`%$&```0````$&EI#0```@!G!@```````!PQ!0@&"0``H#(%"`5<``#`,@4(
M!6,``,0R!0@%=```+#$%"`<!```P,04(!P(``#0Q!0@'`P``.#$%"`<$```\
M,04(!P4``$`Q!0@'!@``1#$%"`<'``!(,04(!P@``$PQ!0@'40``4#$%"`<)
M``!4,04(!PL``%@Q!0@'#```7#$%"`<-``!@,04(!PX``&0Q!0@'#P``:#$%
M"`<0``!L,04(!Q$``'`Q!0@'$@``=#$%"`<3``!X,04(!Q0``'PQ!0@'%0``
M@#$%"`<6``"$,04(!Q<``(@Q!0@'&```C#$%"`<9``"0,04(!QH``)0Q!0@'
M&P``F#$%"`<<``"<,04(!QT``*`Q!0@''@``I#$%"`<?``"H,04(!R```*PQ
M!0@'(0``L#$%"`<B``"T,04(!R,``+@Q!0@')```O#$%"`<E``#`,04(!VX`
M`,0Q!0@'6@``R#$%"`<F``#,,04(!R<``-`Q!0@'*```U#$%"`<I``#8,04(
M!RH``-PQ!0@'*P``X#$%"`<L``#D,04(!RT``.@Q!0@'+@``[#$%"`<O``#P
M,04(!S```/0Q!0@',0``^#$%"`<R``#\,04(!S,````R!0@'-```!#(%"`<U
M```(,@4(!S8```PR!0@'-P``$#(%"`<X```4,@4(!SD``!@R!0@'.@``'#(%
M"`<[```@,@4(!SP``"0R!0@'/0``*#(%"`<^```L,@4(!S\``#`R!0@'0```
M-#(%"`=!```X,@4(!T(``#PR!0@'0P``0#(%"`=$``!$,@4(!T4``$@R!0@'
M1@``3#(%"`='``!0,@4(!T@``%0R!0@'20``6#(%"`=*``!<,@4(!TL``&`R
M!0@'3```9#(%"`=-``!H,@4(!TX``&PR!0@'3P``<#(%"`=0``!5B>53@^P$
MZ`````!;@<,PG```BY/\____A=)T!>BN````Z-4%``#H0#4``%A;R</_-20Q
M!0C_)2@Q!0@`````_R4L,04(:`````#IX/____\E,#$%"&@(````Z=#_____
M)30Q!0AH$````.G`_____R4X,04(:!@```#IL/____\E/#$%"&@@````Z:#_
M____)4`Q!0AH*````.F0_____R5$,04(:#````#I@/____\E2#$%"&@X````
MZ7#_____)4PQ!0AH0````.E@_____R50,04(:$@```#I4/____\E5#$%"&A0
M````Z4#_____)5@Q!0AH6````.DP_____R5<,04(:&````#I(/____\E8#$%
M"&AH````Z1#_____)60Q!0AH<````.D`_____R5H,04(:'@```#I\/[___\E
M;#$%"&B`````Z>#^____)7`Q!0AHB````.G0_O___R5T,04(:)````#IP/[_
M__\E>#$%"&B8````Z;#^____)7PQ!0AHH````.F@_O___R6`,04(:*@```#I
MD/[___\EA#$%"&BP````Z8#^____)8@Q!0AHN````.EP_O___R6,,04(:,``
M``#I8/[___\ED#$%"&C(````Z5#^____)90Q!0AHT````.E`_O___R68,04(
M:-@```#I,/[___\EG#$%"&C@````Z2#^____):`Q!0AHZ````.D0_O___R6D
M,04(:/````#I`/[___\EJ#$%"&CX````Z?#]____):PQ!0AH``$``.G@_?__
M_R6P,04(:`@!``#IT/W___\EM#$%"&@0`0``Z<#]____);@Q!0AH&`$``.FP
M_?___R6\,04(:"`!``#IH/W___\EP#$%"&@H`0``Z9#]____)<0Q!0AH,`$`
M`.F`_?___R7(,04(:#@!``#I</W___\ES#$%"&A``0``Z6#]____)=`Q!0AH
M2`$``.E0_?___R74,04(:%`!``#I0/W___\EV#$%"&A8`0``Z3#]____)=PQ
M!0AH8`$``.D@_?___R7@,04(:&@!``#I$/W___\EY#$%"&AP`0``Z0#]____
M)>@Q!0AH>`$``.GP_/___R7L,04(:(`!``#IX/S___\E\#$%"&B(`0``Z=#\
M____)?0Q!0AHD`$``.G`_/___R7X,04(:)@!``#IL/S___\E_#$%"&B@`0``
MZ:#\____)0`R!0AHJ`$``.F0_/___R4$,@4(:+`!``#I@/S___\E"#(%"&BX
M`0``Z7#\____)0PR!0AHP`$``.E@_/___R40,@4(:,@!``#I4/S___\E%#(%
M"&C0`0``Z4#\____)1@R!0AHV`$``.DP_/___R4<,@4(:.`!``#I(/S___\E
M(#(%"&CH`0``Z1#\____)20R!0AH\`$``.D`_/___R4H,@4(:/@!``#I\/O_
M__\E+#(%"&@``@``Z>#[____)3`R!0AH"`(``.G0^____R4T,@4(:!`"``#I
MP/O___\E.#(%"&@8`@``Z;#[____)3PR!0AH(`(``.F@^____R5`,@4(:"@"
M``#ID/O___\E1#(%"&@P`@``Z8#[____)4@R!0AH.`(``.EP^____R5,,@4(
M:$`"``#I8/O___\E4#(%"&A(`@``Z5#[____)50R!0AH4`(``.E`^____R58
M,@4(:%@"``#I,/O___\E7#(%"&A@`@``Z2#[____)6`R!0AH:`(``.D0^___
M_R5D,@4(:'`"``#I`/O___\E:#(%"&AX`@``Z?#Z____)6PR!0AH@`(``.G@
M^O___R5P,@4(:(@"``#IT/K__P```````````````#'M7HGA@^3P4%12:$#*
M!`AHX,D$"%%6:(#'!`CH(_S___20D)"0D)"0D)"0D)"0D%6)Y5.#[`2`/=@R
M!0@`=3^AW#(%"+L,,`4(@>L(,`4(P?L"@^L!.=AS'HVV`````(/``:/<,@4(
M_Q2%"#`%"*'<,@4(.=ARZ,8%V#(%"`&#Q`1;7<.-="8`C;PG`````%6)Y8/L
M&*$0,`4(A<!T$K@`````A<!T"<<$)!`P!0C_T,G#D)"0D)"0D)"0D)"0D%57
M5E.)PX'L6`$``(/#'(E$)!2-3"08,<"-M"8`````BQ2##\J)%(&#P`&#^!!U
M\(U4)$R-C"1,`0``D(UT)@"+0NPS`C-"U#-"S,'('XE"#(/"!#G*=>B+1"04
MBU0D%(M\)!2+7"04BP"+4@2+?PR+6PB)1"00BT0D%(E4)`R+5"08B7PD!(M,
M)`R)7"0(BT`0P<$>`<*)!"2+1"00P<`%C;P"F7F"6HM$)`R+5"0,]]`C1"0$
M(=H)T(M4)`0!QXM$)!`#5"0<B?WWT"'8BUPD$"'+"=B+7"0(C;0"F7F"6HGX
MBU0D$,'`!0'&`UPD((GPP<`%P<(>C9P#F7F"6HGX]]`AU2'(">B)]0'#B?#!
MQQ[WT`-,)"0A_2'0">B)W8V,`9EY@EJ)V,'`!0'!`U0D*(G(P<`%P<8>C90"
MF7F"6HG8]]`A]2'X">B)S0'"B<C!PQ[WT`-\)"PAW2'P">B)U8V\!YEY@EJ)
MT,'`!0''`W0D,(GXP<`%P<$>C;0&F7F"6HG0]]`AS2'8">B)_0'&B?C!PA[W
MT`-<)#0AU2'(">B)]8V<`YEY@EJ)\,'`!0'#`TPD.(G8P<`%P<<>C8P!F7F"
M6HGP]]`A_2'0">B)W0'!B=C!QA[WT`-4)#PA]2'X">B)S8V4`IEY@EJ)R,'`
M!0'"`WPD0(G0P<`%P<,>C;P'F7F"6HG(]]`AW2'P">B)U0''B=#!P1[WT`-T
M)$0AS2'8">B)_8VT!IEY@EJ)^,'`!0'&`UPD2(GPP<`%P<(>C9P#F7F"6HGX
M]]`AU2'(">B)]0'#B?#!QQ[WT`-,)$PA_2'0">B)W8V,`9EY@EJ)V,'`!0'!
M`U0D4(G(P<8>P<`%(?6-E`*9>8):B=CWT"'X">B)S0'"B<C!PQ[WT`-\)%0A
MW2'P">B)U8V\!YEY@EJ)T,'`!0''`W0D6(GXP<`%P<$>C;0&F7F"6HG0]]`A
MS2'8">B)_0'&B?C!PA[WT`-<)%PAU2'(">B)]8V<`YEY@EJ)\,'`!0'#`TPD
M8(G8P<`%P<<>C8P!F7F"6HGP]]`A_2'0">B)W0'!B=C!QA[WT`-4)&0A]2'X
M">B-E`*9>8):B<C!PQ[!P`4!PHG8`WPD:#'P,<C!P1Z-O`>AZ]ENB=#!P`4#
M="1LC00'B<\QWS'7C;P^H>O9;HG&P<(>P<8%`UPD<(TT-XG7,<\QQXV\.Z'K
MV6Z)\\'`'L'#!0-,)'2-'!^)QS'7,?>-O#FAZ]ENB=G!QA[!P04#5"1XC0P/
MB?<QQS'?C;PZH>O9;HG*P<,>P<(%C107B=\#1"1\,?<QS\'!'HV\.*'KV6Z)
MT,'`!0.T)(````"-!`>)SS'?,=>-O#ZAZ]ENB<;!PA[!Q@4#G"2$````C30W
MB=<QSS''C;P[H>O9;HGSP<`>P<,%`XPDB````(T<'XG',=<Q]XV\.:'KV6Z)
MV<'&'L'!!0.4)(P```"-#`^)]S'',=^-O#JAZ]ENB<K!PQ[!P@4#A"20````
MC107B=\Q]S'/C;PXH>O9;HG0P<$>P<`%`[0DE````(T$!XG/,=\QUXV\/J'K
MV6Z)QL'&!<'"'@.<))@```"--#>)US'/,<>-O#NAZ]ENB?/!P![!PP4#C"2<
M````C1P?B<<QUS'WC;PYH>O9;HG9P<8>P<$%`Y0DH````(T,#XGW,<<QWXV\
M.J'KV6Z)RL'#'L'"!0.$)*0```"-%!>)WS'W,<^-O#BAZ]ENB=#!P1[!P`4#
MM"2H````C00'B<\QWS'7C;P^H>O9;HG&P<(>P<8%`YPDK````(TT-XG7,<\Q
MQXV\.Z'KV6Z)\\'`'L'#!0.,)+````"-'!^)QS'7,?>-O#FAZ]ENB=G!QA[!
MP04#E"2T````C0P/B?<QQS'?C;PZH>O9;HG*P<(%C107B[PDN````,'#'HG=
M(?4!QXG8"?`AR`GHC;P'W+P;CXG0P<`%C00'B[PDO````,'!'HG-(=T!]XG.
M"=XAU@GNC;PWW+P;CXG&P<8%C30WB[PDP````,'"'HG5(<T!WXG3"<LAPPGK
MC;P?W+P;CXGSP<,%C1P?B[PDQ````,'`'HG%`<^)P0G1(?$AU0GIC;P/W+P;
MCXG9P<$%C0P/B[PDR````,'&'HGU(<4!UXGR"<(AV@GJC;P7W+P;CXG*P<(%
MC107B[PDS````,'#'HG=(?4!QXG8"?`AR`GHC;P'W+P;CXG0P<`%C00'B[PD
MT````,'!'HG-(=T!]XG."=XAU@GNC;PWW+P;CXG&P<8%C30WB[PDU````,'"
M'HG5(<T!WXG3"<LAPPGKC;P?W+P;CXGSP<,%C1P?B[PDV````,'`'HG%`<^)
MP0G1(=4A\0GIC;P/W+P;CXG9P<$%C0P/B[PDW````,'&'HGU(<4!UXGR"<(A
MV@GJC;P7W+P;CXG*P<(%C107B[PDX````,'#'HG=(?4!QXG8"?`AR`GHC;P'
MW+P;CXG0P<`%C00'B[PDY````,'!'HG-(=T!]XG."=XAU@GNC;PWW+P;CXG&
MP<8%C30WB[PDZ````,'"'HG5(<T!WXG3"<LAPPGKC;P?W+P;CXGSP<,%C1P?
MB[PD[````,'`'HG%(=4!SXG!"=$A\0GIC;P/W+P;CXG9P<$%C0P/B[PD\```
M`,'&'HGU(<4!UXGR"<(AV@GJC;P7W+P;CXG*P<(%C107B[PD]````,'#'HG=
M(?4!QXG8"?`AR`GHC;P'W+P;CXG0P<`%C00'B[PD^````,'!'HG-(=T!]XG.
M"=XAU@GNC;PWW+P;CXG&P<8%C30WB[PD_````,'"'HG5(<T!WXG3"<LAPPGK
MC;P?W+P;CXGSP<,%C1P?B[PD``$``,'`'HG%(=4!SXG!"=$A\0GIC;P/W+P;
MCXG9P<$%C0P/B[PD!`$``,'&'HGU(<4!UXGR"<(AV@GJC;P7W+P;CXG*P<,>
MP<(%`=>)V@.$)`@!```Q\C'*P<$>C900UL%BRHGXP<`%C00"B<H#M"0,`0``
M,=HQ^@.<)!`!``"-M!;6P6+*B<+!P@6-%!:)_L'&'HGW,<\QQXV\.];!8LJ)
MT\'`'L'#!8T<'XG'`XPD%`$``#'W,=?!PAZ-O#G6P6+*B=G!P04!SXG1`[0D
M&`$``#'!,=G!PQZ-M`[6P6+*B?G!P04!SHG9`X0D'`$``#'1,?D#E"0@`0``
MC8P(UL%BRHGPP<`%`<&)^,'`'HG',=\Q]XV\.M;!8LJ)RL'&'L'"!0'7B?(#
MG"0D`0``,<(QRL'!'HV<$];!8LJ)^L'"!0.$)"@!``"-%!.)RS'S,?N-G!C6
MP6+*B=#!P`4!P\'''@.T)"P!``")^#'(,="-M`;6P6+*B=C!PA[!P`4#C"0P
M`0``C00&B=8Q_C'>C;0QUL%BRHG!P<,>P<$%`<Z)V0.\)#0!```QT3'!P<`>
MC;P/UL%BRHGQP<$%`Y0D.`$``(T,#XG',=\Q]XV\.M;!8LJ)RL'&'L'"!0'7
MB?(#G"0\`0``,<(QRL'!'HV<$];!8LJ)^L'"!0.$)$`!``"-%!.)RS'S,?N-
MG!C6P6+*B=#!P`4!P\'''@.T)$0!``")^#'(,="-M`;6P6+*B=C!PA[!P`6-
M!`:)U@.,)$@!```Q_C'>P<,>C;0QUL%BRHG!P<$%C0P.B=X#O"1,`0``,=8Q
MQL'`'HV\-];!8LJ)SL'&!8TT-XG'`Y0D4`$``#'?,<_!P1Z-O#K6P6+*B?+!
MP@6-%!>+?"00`[PD5`$``(V\.];!8LJ)RS'#,?.-'!^)U\''!0'[BWPD%,'&
M'HD?`U0D#`-,)`0#!"2)5P2+5"0(B4\,B4<0C106B5<(@<18`0``6UY?7</K
M#9"0D)"0D)"0D)"0D)"#[#R)7"0LB<,QP(7;B70D,(E\)#2);"0XB50D''49
MBUPD+(MT)#"+?"0TBVPD.(/$/,.0C70F`(L5P#(%"(72B50D&'39#[8#/#UT
M!(3`=3\Q[8M$)!B+,#'`A?9TP(M\)!B0C70F`(EL)`B)7"0$B30DZ)SR__^%
MP'4&@#PN/70F@\<$BS>%]G7=,<#KD)")W8/%`0^V10`\/70$A,!U\2G=ZZZ-
M=@`K?"08BU0D'(U$+@'!_P*).NEA____9I"#[!R-5"0,Z#3___^#Q!S#5HG&
M4XGP@^P4C5PD#(G:Z!S___^%P'0IBT0D#,'@`@,%P#(%"(UV`(/`!(L0A=*)
M4/QU](G:B?#H\_[__X7`==>#Q!1;7L.)]HV\)P````!64X/L%,<$)`````#H
M,_+__XL`B00DZ!GO__^)!"3HD>W__XL`BW`$QP0D`````.@0\O__BP")!"3H
M]N[__XD$).@N[O__#[88QP0D`````.CO\?__@^-_BP")!"3HTN[__XD$).@:
M[O__BP`/MT`0P>`'"=AFB48"QP0D`````.B_\?__BP")!"3HI>[__XD$).@=
M[?__BP"+6`3'!"0`````Z)SQ__^+`(D$).B"[O__QT0D"`````#'1"0$B,P$
M"(D$).CZ\/__B4,<QP0D`````.AK\?__BP")!"3H4>[__XD$).C)[/__BP"+
M6`3'!"0`````Z$CQ__^+`(D$).@N[O__B00DZ$;M__^+`(E#(,<$)`````#H
M)?'__XL`B00DZ`ON__^)!"3H@^S__XL`BU@$QP0D`````.@"\?__BP")!"3H
MZ.W__XD$).@`\/__,=*+`(7`="/'!"0`````Z-SP__^+`(D$).C"[?__B00D
MZ-KO__^+`(M0;(E3),<$)`````#HMO#__XL`B00DZ)SM__^)!"3H%.S__XL`
MBT`$QT`H`````,<$)`````#HC/#__XL`B00DZ'+M__^)!"3HZNO__XL`BT`$
MQT`8`````,<$)`````#H8O#__XL`B00DZ$CM__^)!"3HP.O__XL`BU@$QP0D
M`````.@_\/__BP")!"3H)>W__XD$).C][___BP")0RR#Q!1;7L.-M"8`````
MC;PG`````%57B<=64X'LC````(7`=`6`.`!U"X'$C````%M>7UW#B00DZ&SM
M__^%P(G&=.=FD(DT).C,[?__A<`/A,@```"-6!,/MA6IR@0(#[9`$SG0=0X/
MMA6JR@0(.%,!=-)FD`^V%:C*!`@YT`^$N0```(D\).B][?__B1PDB<7HL^W_
M_XU$!0*)!"3H1^[__XE<)!2)?"00QT0D#*O*!`C'1"0(_____\=$)`0!````
MB<6)!"3H[>[__XU$)"")1"0(B6PD!,<$)`,```#H9>O__X/X_W00BT0D,"4`
M\```/0!```!T;(DL).A8[?__B2PDZ%#L__^)-"3H".W__X7`#X4\____C70F
M`(DT).B$[?__B3PDZ.SM__^!Q(P```!;7E]=PY"-="8`#[8%J<H$"#A#`0^%
M-____P^V%:K*!`@X4P(/A.C^___I(O___XUV`(GHZ*G^___KDXVT)@````!6
MB<93,=N#[!3'!"0`````Z)_N__^+`(D$).B%Z___B00DZ*WM__^)="0$QP0D
M`P```(E$)`CHR>O__X7`=`F)V(/$%%M>PY#'!"0`````Z&#N__^+`(D$).A&
MZ___B00DZ&[M__^+0!`E`/```#T`0```="W'!"0`````Z#/N__^+`(D$).@9
MZ___B00DZ$'M__^+0!`E`/```#T`H```=9V)-"0QV\=$)`0"````Z&#K__^%
MP`^4PX/$%(G86U[#ZPV0D)"0D)"0D)"0D)"055=6B<93,<"#[#R)TX`Z/0^4
MP`'#B1PDZ.?K__^-5"0LB<>)\.A6^O__A<")Q70XB00DZ,SK__\QTCG'#X>5
M`0``C;8`````#[8$$XA$%0"#P@&$P'7Q,<"#Q#Q;7E]=PXVT)@````"+%<`R
M!0@Q[;@(````BPJ%R706D(UT)@"#Q0&+!*J%P'7VC02M"````(L-\#(%"(7)
M#X3A````B40D!(D4).@YZ?__B<&%R:/`,@4(N/____]TGHT$K0````")1"0<
MQT2I!`````");"0L#[8&/#T/A`H!``"$P`^$`@$``(GPZPN-M"8`````A-)T
M"X/``0^V$(#Z/77Q*?"+;"0<C40'`@,MP#(%"(D$).B-Z___B<*%THE%`+C_
M____#X0P____BU0D+*'`,@4(BP20#[86A-*($'0>@/H]=!F#Q@'K!8#Z/70/
M#[86@\`!@\8!A-*($'7LQ@`],=*-M"8`````#[8,$XA,$`&#P@&$R77QZ=O^
M__^-="8`B50D&,<%\#(%"`$```")!"3H#NO__XM4)!B)P;C_____A<D/A+#^
M__^-!*T`````B0PDB4PD&(E$)!R)1"0(B50D!.A<Z___BTPD&(D-P#(%".GO
M_O__BT0D+,'@`HE$)!SIZ_[__XGPZ1'___]FD('L/!```(F\)#00``"-?"0<
MB9PD+!```(G#B:PD.!```(G59:$4````B80D'!```#'`B;0D,!```,=$)`C_
M#P``B7PD!,<$)+'*!`CHT^K__X7`#XZ'````@'P$&P")QG1VB70D",=$)`0O
M````B3PDZ![K__^%P'1FQP0D`````.ANZ___BP")!"3H5.C__XET)`R)?"0(
MB5PD!(D$).B@Z?__BX0D'!```&4S!10```!U5(N<)"P0``"+M"0P$```B[PD
M-!```(NL)#@0``"!Q#P0``##D(/N`76%C78`QP0D`````.@(Z___BP")!"3H
M[N?__XEL)`B)7"0$B00DZ*[G___KG.C'Z?__C78`@^P<QP0D`````.C5ZO__
MBP")!"3HN^?__\=$)`S`R@0(QT0D"'27!`C'1"0$RLH$"(D$).B+ZO__@\0<
MPXUV`(/L+,<$)`````#HE>K__XL`B00DZ'OG__^)!"3HG____\<$)`````#H
M=^K__XL`B00DZ%WG___'1"04`````,=$)!"(S`0(QT0D#(C,!`C'1"0((,($
M",=$)`3FR@0(B00DZ`WH__^#Q"S#D(UT)@"![#P@``")G"0P(```C9PD*Q``
M`(FT)#0@```Q]F6A%````(F$)"P@```QP(F\)#@@``#H?.7__\=$)!2\R@0(
MQT0D#/O*!`C'1"0(`1```,=$)`0!````B1PDB40D$.A@Z?__A<!Y,(N4)"P@
M``!E,Q44````B?!U8XN<)#`@``"+M"0T(```B[PD."```('$/"```,-FD(U\
M)"J)'"3'1"0(`!```(E\)`3HM.C__X7`B<-XLHU``8D$).@SZ/__A<")QG2A
MB5PD"(E\)`2)!"3H7>?__\8$'@#KB^@RZ/__C;0F`````(V\)P````"#[`R#
MQ`SI!?___Y"-="8`55=64X'L3!```&6A%````(F$)#P0```QP+@'RP0(BYPD
M8!```(NT)&00``#H7_;__\=$)`0O````B1PDB<7H0>7__X7`="V)VK@0RP0(
MZ/WZ__^+E"0\$```93,5%````(G8#X5Y`0``@<1,$```6UY?7<.)'"3HV.;_
M_\=$)`0=RP0(B30DB40D+.BDY___A<")QW2QBU0D+(UT)#R#P@&)5"0LC78`
M@#\`=06_J<H$"(7M=!2)?"0$B2PDZ)+H__^%P`^$Q@```(D\).B"YO__@'P'
M_R]U%8VT)@````"#Z`&`?`?_+\8$!P!T\@-$)"P]_P\```^/2O___XE<)!C'
M1"04'\L$"(E\)!#'1"0,/LP$",=$)`@`$```QT0D!`$```")-"3HE^?__\<$
M)`````#H^^?__XL`B00DZ.'D__^)!"3H">?__XET)`3'!"0#````B40D".CU
MX___A<!U+<<$)`````#HQ>?__XL`B00DZ*OD__^)!"3HT^;__XM`$"4`\```
M/0"```!T(\=$)`0=RP0(QP0D`````.B0YO__A<")QP^%^O[__^F4_O__QT0D
M!`$```")-"3HT>3__X7`=<F)\K@0RP0(Z'WY__^)-"3HF>?__XG#Z7'^___H
M+>;__XGVC;PG`````(M$)`0/M@B$R70@C5`!ZPH/M@J#P@&$R701@/DO=?$/
MM@J)T(/"`83)=>_SPXUV`%.#[!B+7"0@A=MT+(`[`'0GB1PDZ!OE__^-1`/_
M.<-R#NM!D(UT)@"#Z`$YPW,U@#@O=/3K)V:0QP0D`@```.B0Y?__A<!T!6;'
M`"X`@\086\.-M@````"`."]T!X/H`3G#<O0YV'48@#@O=%O'1"0@'\L$"(/$
M&%OIUN;__V:0@^@!.<-S!8`X+W3TB<(QP"G:C4H"@?D`$```=["#P@''1"0,
M`!```(E4)`B)7"0$QP0D`#,%".@(XO__N``S!0CKBI"-="8`QP0D`@```.@`
MY?__B<(QP(72#X1M____9L<"+@")T.EA____C70F`%=6@^PT9:$4````B40D
M+#'`H93,!`B)1"0*H9C,!`B)1"0.H9S,!`B)1"02H:#,!`B)1"06H:3,!`B)
M1"0:H:C,!`B)1"0>H:S,!`B)1"0BH;#,!`B)1"0F#[<%M,P$"&:)1"0JN"'+
M!`CH(?/__[@JRP0(Z!?S__^X,LL$".@-\___N#O+!`CH`_/__[A"RP0(Z/GR
M__^X4LL$".CO\O__N`?+!`CHY?+__[A>RP0(Z-OR__^X:,L$".C1\O__N'++
M!`CHQ_+__[@0RP0(Z+WR__^X?,L$".BS\O__N(7+!`CHJ?+__[B0RP0(Z(_R
M__^%P'0,B<*X:,L$".@_]___N*'+!`CH=?+__X7`=`R)PKBSRP0(Z"7W__^X
MOLL$".A;\O__A<!T+XG"N`?+!`CH"_?__[KJRP0(N$++!`CH_/;__XM$)"QE
M,P44````=4F#Q#1>7\.0N,[+!`CH'O+__X7`=!*)PKA>RP0(Z,[V___KP8UT
M)@"-="0;O]_+!`BY"@```/.F=:N-5"0EN%[+!`CHJ/;__^N;Z&7C__^0@^P,
MH7PR!0B#^/]T"X/$#,.-M"8`````N%[+!`CHOO'__XG",<"%TG0/#[82A-)T
M"#'`@/HP#Y7`HWPR!0B#Q`S#C;0F`````(V\)P````"#[!SHC.+__XD$).AD
MXO__B<(QP(72=`*+`H/$',-FD%575E.[]LL$"(/L7(M\)'"-="0XQT0D-/;+
M!`C'1"0X[,L$",=$)#SYRP0(QT0D0._+!`C'1"1$],L$",=$)$@&S`0(QT0D
M3(C,!`CK'&:0B7PD!(D$).AHXO__A<!T.(L>@\8$@#L`="6)V.C_\/__A<")
MQ70%@#@`==2)V(GZZ*OU__^+'H/&!(`[`'7;@\1<6UY?7<.0B3PDZ)3A__^)
M+"2)1"0LZ(CA__^+5"0LC40"`HD$).@8XO__B6PD&,=$)!0=RP0(B7PD$,=$
M)`P^S`0(QT0D"/_____'1"0$`0```(D$)(E$)"SHM.+__XM4)"R)V.@U]?__
MZ6#___]55U93@>R<@0``BX0DL($``&6+%10```")E"2,@0``,=+'A"3@````
M'<P$",>$).0```"IR@0(B40D1+@'RP0(QX0DZ````(C,!`C'A"2\````L\L$
M",>$),````"LRP0(QX0DQ````"+,!`C'A"3(````R<L$",>$),P````JS`0(
MQX0DT````(C,!`C'A"34````$<P$",>$)-@````NS`0(QX0DW````(C,!`CH
MO>___X7`=`F`.``/A<@#``#H&_[__X7`B<</A.$#```/MA^$VW0BZ-G?__^)
M^HUV`(L(#[[;]@19"'4#Q@)?@\(!#[8:A-MUZ+X!````N+/+!`CK%XUT)@"+
MA+2\````@\8!@#@`#X05`P``Z%#O__^%P(G#=.+H-?/__X7`=-F)'"3H'>+_
M_X7`=,V)Q8DL).COW___B3PDB</HY=___XVT`P0$``")-"3H=N#__XE\)!S'
M1"08-\P$",=$)!0?RP0(B6PD$,=$)`P\S`0(B</'1"0(_____\=$)`0!````
MB00DZ`SA___'1"0$P`$``(D<).C\W/__@_C_=1#HPMS__XL`@_@1#X4X`P``
MC40D7(E$)`B)7"0$QP0D`P```.B/WO__@_C_#X34"```BT0D;"4`\```/0!`
M```/A>8!``"+?"1TZ'G?__\YQP^%U0$``(M$)&PE_P$``#W``0``#X7!`0``
MB30DZ+7?__^)1"1(B<6X[\L$".A![O__A<`/A/H"``")!"3H%>'__XM4)$2)
M1"0$BP*)!"3HC_?__X7`B40D3`^$U`(``(M$)$R)!"3HR][__X/X`WYBBU0D
M3+]%S`0(N04```"-=`+\\Z9U3(/X!'0+BWPD3(!\!_LO=3R+1"1$BU`$A=)T
M,8D4)(E4)$#HB=[__XM4)$"#^`-V'(UT`OR_2LP$"+D%````\Z9U"HE4)$R-
MM@````#HN_O__X7`=2"+5"1,QT0D!`````")%"3HY]___X7`B40D1`^%1P(`
M`+KJRP0(N%[+!`CH*/+__S'VZ(7;___'1"0<B,P$",=$)!0?RP0(B5PD$,=$
M)`QCS`0(QT0D"/____^)1"08QT0D!`$```")+"3H7=___^M5C;0F`````.@?
MV___@S@1=5GH-=O__X/&`<=$)""(S`0(B70D',=$)!0?RP0(B5PD$,=$)`QQ
MS`0(B40D&,=$)`C_____QT0D!`$```")+"3H!M___\=$)`3``0``B2PDZ/;:
M__^#^/]TG8D<).B)W/__B>JX!\L$".AI\?__B2PDZ#'[___K.HVT)@````"+
M?"1$B5PD$(L'QT0D""S-!`C'1"0$`0```(E$)`RAH#(%"(D$).CAVO__QT0D
M2`````"+E"2,@0``93,5%````(M$)$@/A4@'``"!Q)R!``!;7E]=PV:0BYPD
MX````+X!````@#L`=1;K/I"-="8`BYRTX````(/&`8`[`'0JB=CH`O#__X7`
M=.:)'"3HZM[__X7`#X7)_/__BYRTX````(/&`8`[`'76,>WIM?S__XD$)(E$
M)$#H;/K__XM$)$")!"3HM-[__XE$)$CI8O___XVT)@````"[`0```+@1S`0(
MZQ.-="8`BX2<U````(/#`8`X`'0<Z)SK__^%P'3HB00DZ'3>__^%P'3<B<?I
MY/O__[\6S`0(Z0/\__^+?"1$B40D%(E<)!"+!\=$)`BXS`0(B40D#*&@,@4(
MQT0D!`$```")!"3HP-G__\=$)$@`````Z=K^__^+?"1$BS^)?"1,Z1W]___'
M1"0,`@```(V\).P```#'1"0$[O___\=$)`C_____B00DZ!W:__^+1"1$QT0D
M"`8```")?"0$B00DZ)7:__^`O"3L`````'4.@+PD[0```$,/A$$%``"+?"1$
MQT0D#`````#'1"0$`````,=$)`@`````B3PDZ,G9__^-A"0(@0``B6PD3(G=
MQX0D[(````$C16?'A"3P@```B:O-[\>$)/2```#^W+J8QX0D^(```'94,A#'
MA"3\@```\.'2P\>$)`"!````````QX0D!($```````#'A"1(@0```````(E$
M)#R-="8`BT0D1(V\).P```#'1"0(`(```(E\)`2)!"3HS=G__X7`B<8/CL`!
M``"+E"0`@0``B?.-O"3L````C03R.=`/DL(/MM*)A"0`@0``B?`!E"0$@0``
MP>@=`80D!($``(N$)$B!``"%P'1GND````")]RG".=9^`HG7C90D"($``(T$
M`HV4).P```")?"0(B50D!(D$).A3VO__BX0D2($```'X@_A`B80D2($```^%
M3O___XV$).P```")\RG[C3PXC80D[(```.ALW?__C70F`(/[/P^.Y0```#'V
MD(UT)@"+!#>)A"0(@0``BT0W!(F$)`R!``"+1#<(B80D$($``(M$-PR)A"04
M@0``BT0W$(F$)!B!``"+1#<4B80D'($``(M$-QB)A"0@@0``BT0W'(F$)"2!
M``"+1#<@B80D*($``(M$-R2)A"0L@0``BT0W*(F$)#"!``"+1#<LB80D-($`
M`(M$-S")A"0X@0``BT0W-(F$)#R!``"+1#<XB80D0($``(M$-SR#QD")A"1$
M@0``C80D[(```.B:W/__B=@I\(/X/P^/-?___X/K0(G8P>@&B<+!X@:-?#I`
M*=.-E"0(@0``QT0D#$0```")7"0(B7PD!(D4).COU___B9PD2($``.D7_O__
MBU0D1(GKBVPD3(D4).B!V?__B[0D`($``(N4)`2!``")\,'H`X/@/\:$!`B!
M``"`@\`!@_@X#X\:`@``N3@```"-O"0(@0``*<&-!`>)5"1`B4PD",=$)`0`
M````B00DZ$[7__^+5"1`B=#!Z!B(A"1`@0``B=#!Z!"(A"1!@0``B=#!Z`B(
MA"1"@0``B?#!Z!B(A"1$@0``B?#!Z!"(A"1%@0``B?#!Z`B(A"1&@0``B?`Q
M]HB$)$>!``"-A"3L@```B)0D0X$``(V\)$^!``#H>=O__XN4).R```")T<'I
M&(G(B(PD>($``(G1P>D0B(PD>8$``(G1B)0D>X$``(N4)/"```#!Z0B(C"1Z
M@0``B='!Z1B(C"1\@0``B='!Z1"(C"1]@0``B=&(E"1_@0``BY0D](```,'I
M"(B,)'Z!``")T<'I&(B,)("!``")T<'I$(B,)(&!``")T8B4)(.!``"+E"3X
M@```P>D(B(PD@H$``(G1P>D8B(PDA($``(G1P>D0B(PDA8$``(G1B)0DAX$`
M`(N4)/R```#!Z0B(C"2&@0``B='!Z1B(C"2(@0``B='!Z1"(C"2)@0``B='!
MZ0B(C"2*@0``B)0DBX$``.L+C78`#[:$-'B!```/ML")1"00C01W@\8!QT0D
M#%[,!`C'1"0(_____\=$)`0!````B00DZ(?8__^#_A1UQL:$)'>!````QT0D
M'(C,!`B)?"08QT0D%!_+!`B)7"00QT0D#$_,!`C'1"0(_____\=$)`0!````
MB2PDZ$+8___I3/G__XV\)`B!``"Y0````"G!C00'B4PD"(E4)$#'1"0$````
M`(D$).@TU?__C80D[(```.C$V?__BWPD/+D.````,<#SJXM4)$#IR/W__^B]
MT___BU0D1(L`B5PD$(E$)!2+`L=$)`CTS`0(B40D#.DW^O__@+PD[@```$$/
MA;'Z__^`O"3O````0P^%H_K__X"\)/````!(#X65^O__@+PD\0```$4/A8?Z
M__^+5"1$C;PD[````,=$)`P"````QT0D!,;____'1"0(_____XD4).A)U/__
MBT0D1,=$)`@I````B7PD!(D$).C!U/__C90D[````,=$)!R(S`0(B50D&.G+
M_O__Z(36__]55U93@^P<QP0D`````.B1U___BP")!"3H=]3__XD$).COU/__
MQ@`!N$++!`CHSN3__X7`=`F`.#$/A`$#``"0Z#OQ___'!"0`````Z%/7__^+
M`(D$).@YU/__QT0D#`L```#'1"0(`0```,=$)`2"S`0(B00DZ,G3__^%P`^$
MS0```(M`##'VBV@8H>@R!0B#^`$/CJP```"[`0```.LOBT<,BQ7D,@4(BQ2:
MB40D!(D4).@,U___A<`/A8````"AZ#(%"(/#`8/&`3G8?G;'!"0`````Z,G6
M__^+`(D$).BOT___QT0D#`````")="0(B6PD!(D$).@7U?__A<!T/XLX]D<)
M!'67QP0D`````.B/UO__BP")!"3H==/__\=$)`P"````QT0D"`````")?"0$
MB00DZ-G6___I8____Z'H,@4(C5#_.?(/A(`!``#'!"0`````Z$C6__^+`(D$
M).@NT___QT0D#`0```#'1"0(`0```,=$)`2'S`0(B00DZ+[2__^%P(G#=#Z+
M0`R+,,<$)`````#H!];__XL`B00DZ.W2___'1"0(B<P$"(ET)`2)!"3HJ=+_
M_XM##(L8]D,*0`^%3@$``,<$)`````#HSM7__XL`B00DZ+32___'1"0,!```
M`,=$)`@!````QT0D!([+!`B)!"3H1-+__X7`B<-T/[@0RP0(Z/#B__^%P(G&
M#X0^`0``BT,,BSC'!"0`````Z'G5__^+`(D$).A?TO__B70D"(E\)`2)!"3H
M']+__\<$)`````#H4]7__XL`B00DZ#G2__^)!"3HL=+__\8``,<$)`````#H
M,M7__XL`B00DZ!C2__^)!"3H4-7__\<``````+@'RP0(Z&SB__^%P*/L,@4(
M#X3G````QT0D!.T!``")!"3H@]#__X/X$700A<!T#(/X_XUV``^%)P$``(/$
M'%M>7UW#9I"#^`$/CG?^__^[`0```&:0QP0D`````(/#`>BUU/__BP")!"3H
MF]'__XEL)`2)!"3H+]'__SD=Z#(%"'_3Z3[^__^-M@````#'!"0`````Z(#4
M__^+`(D$).AFT?__B5PD!(D$).@ZT___Z8O^__^0@'@!``^$^_S__XVV````
M`.GJ_/__C78`H>0R!0B+.(M##(LPQP0D`````.@TU/__BP")!"3H&M'__XGZ
MB?#H+>C__^F]_O__H>0R!0B)!"3H^_#__XL]Y#(%"*/L,@4(BT,,BS#V1@D$
M#X26````BT8,B7PD!(D$).CVT?__B<:+0PR+&/9#"01T1HM##(E$)`BAY#(%
M"(ET)`R+`,<$)(#-!`B)1"0$Z`?3__^)1"0,H>PR!0B)1"0(H>0R!0B+`,<$
M)+#-!`B)1"0$Z./2___'!"0`````Z(?3__^+`(D$).AMT/__QT0D#`(```#'
M1"0(`````(E<)`2)!"3HT=/__^N)QP0D`````.A3T___BP")!"3H.=#__\=$
M)`P"````QT0D"`````")="0$B00DZ)W3___I-O___XUT)@!64X/L%(MT)"")
M-"3H_^O__P^V$(G#A-)U$.L?C70F`(/``0^V$(32=!&`^B]U\8/``0^V$(G#
MA-)U[^A@[O__A<!T'87V=!F`/@!T%,=$)`0WS`0(B1PDZ'?1__\YV'0&@\04
M6U[#@\04B?!;7NF=XO__C;8`````C;PG`````(/L',<$)`````#HE=+__XL`
MB00DZ'O/___'1"0$_____XD$).B[S___QP0D`````.AOTO__BP")!"3H5<__
M_\=$)`@`````QT0D!("G!`B)!"3HK=+__X/$',.0C70F`%6)Y8/D\%93@^PX
MC440B40D"(U%#(E$)`2-10B)!"3H$-+__\=$)`BDE00(QT0D!*25!`C'!"2$
MEP0(Z.`!``#'!"0`````Z!C/__^`.`!U.^C^SO__A<"CX#(%"`^$L0$``(D$
M).BYS___QP0D`````.C-T?__BP")!"3HL\[__XD$).@;T?__Q@``QP0D````
M`#';Z*K1__^+`(D$).B0SO__B00DZ*C1__^`"`+'!"0`````Z(G1__^+`(D$
M).AOSO__B00DZ(?1__^`"`&+50B)7"0L@\(%B50D*-]L)"C8!0#.!`C=!0C.
M!`C9R=KIW^">#X<%`0``P>("B10DZ*[0__^+=0RCY#(%"(L6QT`$CLP$",=`
M""#.!`C'0`R1S`0(B1"+70C'!>@R!0@$````@_L!?A6Z`0```&:0BPR6B4R0
M#(/"`3G:=?*#PP/'!)@`````B40D#*'@,@4(B5PD",=$)!``````QT0D!""O
M!`B)!"3HA\S__X7`B<-T/:'@,@4(B00DZ%3/__^X4LL$".@&WO__A<!T.J'@
M,@4(B00DZ#G,___H),[__X/$.(G86UZ)[%W#D(UT)@"AX#(%"(D$).CWS/__
MB</KLHVT)@````"A[#(%"(7`=`J)!"3H-_W__^NSN`?+!`CHJ]W__X7`H^PR
M!0ATH.OAQT0D!,0R!0C'!"0$RP0(Z(#/___'!"0!````Z'30__]5B>53Z#(`
M``"!PW=G``"#[!"+@U@!``")1"0,BT40B40D"(M%#(E$)`2+10B)!"3H3\S_
M_X/$$%M=PXL<),.058GE5U93Z/#___^!PS5G``"#[!SHZ\K__XV[X/[__XV#
MX/[__RG'P?\"A?]T)#'VBT40B40D"(M%#(E$)`2+10B)!"3_E+/@_O__@\8!
M.?YRWH/$'%M>7UW#C;8`````58GE7<.0D)"0D)"0D)"0D%6)Y5.#[`2A`#`%
M"(/X_W03NP`P!0AFD(/K!/_0BP.#^/]U](/$!%M=PY"058GE4X/L!.@`````
M6X'#F&8``.CLS___65O)PP```````````P````$``@`N+@`E<R\E<P`O<')O
M8R]S96QF+V5X90!P97)L>'-I+F,`1'EN84QO861E<CHZ8F]O=%]$>6YA3&]A
M9&5R`$EN=&5R;F%L<SHZ4$%2.CI"3T]4`"]P<F]C+R5I+R5S`%!!4E]414U0
M`%!!4E]04D]'3D%-10`Z`"\`4$523#5,24(`4$523$Q)0@!015),-4]05`!0
M15),24\`4$%27TE.251)04Q)6D5$`%!!4E]34$%73D5$`%!!4E]#3$5!3@!0
M05)?1$5"54<`4$%27T-!0TA%`%!!4E]!4D=#`%!!4E]!4D=67S``4$%27T=,
M3T)!3%]$14)51P!005)?1TQ/0D%,7U1-4$1)4@!005)?5$U01$E2`%!!4E]'
M3$]"04Q?5$5-4`!005)?1TQ/0D%,7T-,14%.`%!!4E]#3$5!3CT`,0!,24)0
M051(`$193$1?3$E"4D%265]0051(`%-(3$E"7U!!5$@`55-%4@!365-414T`
M+W1M<`!414U01$E2`%1-4`!54T523D%-10!P87(M`"5S)7,E<R5S`'!A<FP`
M+G!A<@`E<R5S8V%C:&4M)7,E<P`E,#)X`"5S)7-T96UP+25U)7,`)7,E<W1E
M;7`M)74M)74E<P!!4D=6`!@`<&5R;``M90`M+0!?7T5.5E]005)?0TQ%04Y?
M7R`@("`@("`@("`@("`@(``````E<SH@8W)E871I;VX@;V8@<')I=F%T92!S
M=6)D:7)E8W1O<GD@)7,@9F%I;&5D("AE<G)N;STE:2D*```E<SH@<W1A="!O
M9B!P<FEV871E('-U8F1I<F5C=&]R>2`E<R!F86EL960@*&5R<FYO/25I*0H`
M`"5S.B!P<FEV871E('-U8F1I<F5C=&]R>2`E<R!I<R!U;G-A9F4@*'!L96%S
M92!R96UO=F4@:70@86YD(')E=')Y('EO=7(@;W!E<F%T:6]N*0H``"5S.B!E
M>&5C=71I;VX@;V8@)7,@9F%I;&5D("T@86)O<G1I;F<@=VET:"`E:2X*`"5S
M.B!C<F5A=&EO;B!O9B!P<FEV871E('1E;7!O<F%R>2!S=6)D:7)E8W1O<GD@
M)7,@9F%I;&5D("T@86)O<G1I;F<@=VET:"`E:2X*`````````````````(#_
M___/07!A<BYP;``````````````C(2]U<W(O8FEN+W!E<FP*979A;"`G97AE
M8R`O=7-R+V)I;B]P97)L("`M4R`D,"`D>S$K(B1`(GTG"B`@("!I9B`P.R`C
M(&YO="!R=6YN:6YG('5N9&5R('-O;64@<VAE;&P*"G!A8VMA9V4@7U]P87)?
M<&P["@HC("TM+2!4:&ES('-C<FEP="!M=7-T(&YO="!U<V4@86YY(&UO9'5L
M97,@870@8V]M<&EL92!T:6UE("TM+0HC('5S92!S=')I8W0["@HC;&EN92`Q
M-3@*"FUY("@D<&%R7W1E;7`L("1P<F]G;F%M92P@0'1M<&9I;&4I.PI%3D0@
M>R!I9B`H)$5.5GM005)?0TQ%04Y]*2!["B`@("!R97%U:7)E($9I;&4Z.E1E
M;7`["B`@("!R97%U:7)E($9I;&4Z.D)A<V5N86UE.PH@("`@<F5Q=6ER92!&
M:6QE.CI3<&5C.PH@("`@;7D@)'1O<&1I<B`]($9I;&4Z.D)A<V5N86UE.CID
M:7)N86UE*"1P87)?=&5M<"D["B`@("!O=71S*'%Q>U)E;6]V:6YG(&9I;&5S
M(&EN("(D<&%R7W1E;7`B?2D["B`@("!&:6QE.CI&:6YD.CIF:6YD9&5P=&@H
M<W5B('L@*"`M9"`I(#\@<FUD:7(@.B!U;FQI;FL@?2P@)'!A<E]T96UP*3L*
M("`@(')M9&ER("1P87)?=&5M<#L*("`@(",@1&]N)W0@<F5M;W9E('1O<&1I
M<B!B96-A=7-E('1H:7,@8V%U<V5S(&$@<F%C92!W:71H(&]T:&5R(&%P<',*
M("`@(",@=&AA="!A<F4@=')Y:6YG('1O('-T87)T+@H*("`@(&EF("@M9"`D
M<&%R7W1E;7`@)B8@)%Y/(&YE("=-4U=I;C,R)RD@>PH@("`@("`@(",@4V]M
M971H:6YG('=E;G0@=W)O;F<@=6YL:6YK:6YG('1H92!T96UP;W)A<GD@9&ER
M96-T;W)Y+B`@5&AI<PH@("`@("`@(",@='EP:6-A;&QY(&AA<'!E;G,@;VX@
M<&QA=&9O<FUS('1H870@9&ES86QL;W<@=6YL:6YK:6YG('-H87)E9`H@("`@
M("`@(",@;&EB<F%R:65S(&%N9"!E>&5C=71A8FQE<R!T:&%T(&%R92!I;B!U
M<V4N(%5N;&EN:R!W:71H(&$@8F%C:V=R;W5N9`H@("`@("`@(",@<VAE;&P@
M8V]M;6%N9"!S;R!T:&4@9FEL97,@87)E(&YO(&QO;F=E<B!I;B!U<V4@8GD@
M=&AI<R!P<F]C97-S+@H@("`@("`@(",@1&]N)W0@9&\@86YY=&AI;F<@;VX@
M5VEN9&]W<R!B96-A=7-E(&]U<B!P87)E;G0@<')O8V5S<R!W:6QL"B`@("`@
M("`@(R!T86ME(&-A<F4@;V8@8VQE86YI;F<@=&AI;F=S('5P+@H*("`@("`@
M("!M>2`D=&UP(#T@;F5W($9I;&4Z.E1E;7`H"B`@("`@("`@("`@(%1%35!,
M051%(#T^("=T;7!86%A86"<L"B`@("`@("`@("`@($1)4B`]/B!&:6QE.CI"
M87-E;F%M93HZ9&ER;F%M92@D=&]P9&ER*2P*("`@("`@("`@("`@4U5&1DE8
M(#T^("<N8VUD)RP*("`@("`@("`@("`@54Y,24Y+(#T^(#`L"B`@("`@("`@
M*3L*"B`@("`@("`@<')I;G0@)'1M<"`B(R$O8FEN+W-H"G@],3L@=VAI;&4@
M6R!<)'@@+6QT(#$P(%T[(&1O"B`@(')M("UR9B`G)'!A<E]T96UP)PH@("!I
M9B!;(%PA("UD("<D<&%R7W1E;7`G(%T[('1H96X*("`@("`@(&)R96%K"B`@
M(&9I"B`@('-L965P(#$*("`@>#U@97AP<B!<)'@@*R`Q8`ID;VYE"G)M("<B
M("X@)'1M<"T^9FEL96YA;64@+B`B)PHB.PH@("`@("`@("`@("!C:&UO9"`P
M-S`P+"1T;7`M/F9I;&5N86UE.PH@("`@("`@(&UY("1C;60@/2`D=&UP+3YF
M:6QE;F%M92`N("<@/B]D978O;G5L;"`R/B8Q("8G.PH@("`@("`@(&-L;W-E
M("1T;7`["B`@("`@("`@<WES=&5M*"1C;60I.PH@("`@("`@(&]U=',H<7$H
M4W!A=VYE9"!B86-K9W)O=6YD('!R;V-E<W,@=&\@<&5R9F]R;2!C;&5A;G5P
M.B`I"B`@("`@("`@("`@("`N("1T;7`M/F9I;&5N86UE*3L*("`@('T*?2!]
M"@I"14=)3B!["B`@("!);G1E<FYA;',Z.E!!4CHZ0D]/5"@I(&EF(&1E9FEN
M960@)DEN=&5R;F%L<SHZ4$%2.CI"3T]4.PH*("`@(&5V86P@>PH*7W!A<E]I
M;FET7V5N=B@I.PH*:68@*&5X:7-T<R`D14Y6>U!!4E]!4D=67S!](&%N9"`D
M14Y6>U!!4E]!4D=67S!]("D@>PH@("`@0$%21U8@/2!M87`@)$5.5GLB4$%2
M7T%21U9?)%\B?2P@*#$@+BX@)$5.5GM005)?05)'0WT@+2`Q*3L*("`@("0P
M(#T@)$5.5GM005)?05)'5E\P?3L*?0IE;'-E('L*("`@(&9O<B`H:V5Y<R`E
M14Y6*2!["B`@("`@("`@9&5L971E("1%3E9[)%]](&EF("]>4$%27T%21U9?
M+SL*("`@('T*?0H*;7D@)'%U:65T(#T@(21%3E9[4$%27T1%0E5'?3L*"B,@
M9FEX("1P<F]G;F%M92!I9B!I;G9O:V5D(&9R;VT@4$%42`IM>2`E0V]N9FEG
M(#T@*`H@("`@<&%T:%]S97`@("`@/3X@*"1>3R`]?B`O7DU35VEN+R`_("<[
M)R`Z("<Z)RDL"B`@("!?97AE("`@("`@("`]/B`H)%Y/(#U^("]>*#\Z35-7
M:6Y\3U,R?&-Y9W=I;BDO(#\@)RYE>&4G(#H@)R<I+`H@("`@7V1E;&EM("`@
M("`@/3X@*"1>3R`]?B`O7DU35VEN?$]3,B\@/R`G7%PG(#H@)R\G*2P**3L*
M"E]S971?<')O9VYA;64H*3L*7W-E=%]P87)?=&5M<"@I.PH*(R!-86=I8R!S
M=')I;F<@8VAE8VMI;F<@86YD(&5X=')A8W1I;F<@8G5N9&QE9"!M;V1U;&5S
M('M[>PIM>2`H)'-T87)T7W!O<RP@)&1A=&%?<&]S*3L*>PH@("`@;&]C86P@
M)%-)1WM?7U=!4DY?7WT@/2!S=6(@>WT["@H@("`@(R!#:&5C:R!F:6QE('1Y
M<&4L(&=E="!S=&%R="!O9B!D871A('-E8W1I;VX@>WM["B`@("!O<&5N(%]&
M2"P@)SPG+"`D<')O9VYA;64@;W(@;&%S=#L*("`@(&)I;FUO9&4H7T9(*3L*
M"B`@("!M>2`D8G5F.PH@("`@<V5E:R!?1D@L("TX+"`R.PH@("`@<F5A9"!?
M1D@L("1B=68L(#@["B`@("!L87-T('5N;&5S<R`D8G5F(&5Q(")<;E!!4BYP
M;5QN(CL*"B`@("!S965K(%]&2"P@+3$R+"`R.PH@("`@<F5A9"!?1D@L("1B
M=68L(#0["B`@("!S965K(%]&2"P@+3$R("T@=6YP86-K*").(BP@)&)U9BDL
M(#(["B`@("!R96%D(%]&2"P@)&)U9BP@-#L*"B`@("`D9&%T85]P;W,@/2`H
M=&5L;"!?1D@I("T@-#L*("`@(",@?7U]"@H@("`@(R!%>'1R86-T:6YG(&5A
M8V@@9FEL92!I;G1O(&UE;6]R>2![>WL*("`@(&UY("5R97%U:7)E7VQI<W0[
M"B`@("!W:&EL92`H)&)U9B!E<2`B1DE,12(I('L*("`@("`@("!R96%D(%]&
M2"P@)&)U9BP@-#L*("`@("`@("!R96%D(%]&2"P@)&)U9BP@=6YP86-K*").
M(BP@)&)U9BD["@H@("`@("`@(&UY("1F=6QL;F%M92`]("1B=68["B`@("`@
M("`@;W5T<RAQ<2A5;G!A8VMI;F<@9FEL92`B)&9U;&QN86UE(BXN+BDI.PH@
M("`@("`@(&UY("1C<F,@/2`H("1F=6QL;F%M92`]?B!S?%XH6V$M9EQD77LX
M?2DO?'P@*2`_("0Q(#H@=6YD968["B`@("`@("`@;7D@*"1B87-E;F%M92P@
M)&5X="D@/2`H)&)U9B`]?B!M?"@_.BXJ+RD_*"XJ*2A<+BXJ*7PI.PH*("`@
M("`@("!R96%D(%]&2"P@)&)U9BP@-#L*("`@("`@("!R96%D(%]&2"P@)&)U
M9BP@=6YP86-K*").(BP@)&)U9BD["@H@("`@("`@(&EF("AD969I;F5D*"1E
M>'0I(&%N9"`D97AT("%^("]<+B@_.G!M?'!L?&EX?&%L*20O:2D@>PH@("`@
M("`@("`@("!M>2`H)&]U="P@)&9I;&5N86UE*2`](%]T96UP9FEL92@D97AT
M+"`D8W)C*3L*("`@("`@("`@("`@:68@*"1O=70I('L*("`@("`@("`@("`@
M("`@(&)I;FUO9&4H)&]U="D["B`@("`@("`@("`@("`@("!P<FEN="`D;W5T
M("1B=68["B`@("`@("`@("`@("`@("!C;&]S92`D;W5T.PH@("`@("`@("`@
M("`@("`@8VAM;V0@,#<U-2P@)&9I;&5N86UE.PH@("`@("`@("`@("!]"B`@
M("`@("`@("`@("1005(Z.DAE879Y.CI&=6QL0V%C:&5[)&9U;&QN86UE?2`]
M("1F:6QE;F%M93L*("`@("`@("`@("`@)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H
M97LD9FEL96YA;65](#T@)&9U;&QN86UE.PH@("`@("`@('T*("`@("`@("!E
M;'-I9B`H("1F=6QL;F%M92`]?B!M?%XO/W-H;&EB+WP@86YD(&1E9FEN960@
M)$5.5GM005)?5$5-4'T@*2!["B`@("`@("`@("`@(",@<VAO=6QD(&)E(&UO
M=F5D('1O(%]T96UP9FEL92@I"B`@("`@("`@("`@(&UY("1F:6QE;F%M92`]
M("(D14Y6>U!!4E]414U0?2\D8F%S96YA;64D97AT(CL*("`@("`@("`@("`@
M;W5T<R@B4TA,24(Z("1F:6QE;F%M95QN(BD["B`@("`@("`@("`@(&]P96X@
M;7D@)&]U="P@)SXG+"`D9FEL96YA;64@;W(@9&EE("0A.PH@("`@("`@("`@
M("!B:6YM;V1E*"1O=70I.PH@("`@("`@("`@("!P<FEN="`D;W5T("1B=68[
M"B`@("`@("`@("`@(&-L;W-E("1O=70["B`@("`@("`@?0H@("`@("`@(&5L
M<V4@>PH@("`@("`@("`@("`D<F5Q=6ER95]L:7-T>R1F=6QL;F%M97T@/0H@
M("`@("`@("`@("`D4$%2.CI(96%V>3HZ36]D=6QE0V%C:&5[)&9U;&QN86UE
M?2`]('L*("`@("`@("`@("`@("`@(&)U9B`]/B`D8G5F+`H@("`@("`@("`@
M("`@("`@8W)C(#T^("1C<F,L"B`@("`@("`@("`@("`@("!N86UE(#T^("1F
M=6QL;F%M92P*("`@("`@("`@("`@?3L*("`@("`@("!]"B`@("`@("`@<F5A
M9"!?1D@L("1B=68L(#0["B`@("!]"B`@("`C('U]?0H*("`@(&QO8V%L($!)
M3D,@/2`H<W5B('L*("`@("`@("!M>2`H)'-E;&8L("1M;V1U;&4I(#T@0%\[
M"@H@("`@("`@(')E='5R;B!I9B!R968@)&UO9'5L92!O<B`A)&UO9'5L93L*
M"B`@("`@("`@;7D@)&9I;&5N86UE(#T@9&5L971E("1R97%U:7)E7VQI<W1[
M)&UO9'5L97T@?'P@9&\@>PH@("`@("`@("`@("!M>2`D:V5Y.PH@("`@("`@
M("`@("!F;W)E86-H("AK97ES("5R97%U:7)E7VQI<W0I('L*("`@("`@("`@
M("`@("`@(&YE>'0@=6YL97-S("]<421M;V1U;&5<120O.PH@("`@("`@("`@
M("`@("`@)&ME>2`]("1?.R!L87-T.PH@("`@("`@("`@("!]"B`@("`@("`@
M("`@(&1E;&5T92`D<F5Q=6ER95]L:7-T>R1K97E](&EF(&1E9FEN960H)&ME
M>2D["B`@("`@("`@?2!O<B!R971U<FX["@H@("`@("`@("1)3D-[)&UO9'5L
M97T@/2`B+VQO861E<B\D9FEL96YA;64O)&UO9'5L92(["@H@("`@("`@(&EF
M("@D14Y6>U!!4E]#3$5!3GT@86YD(&1E9FEN960H)DE/.CI&:6QE.CIN97<I
M*2!["B`@("`@("`@("`@(&UY("1F:"`]($E/.CI&:6QE+3YN97=?=&UP9FEL
M92!O<B!D:64@)"$["B`@("`@("`@("`@(&)I;FUO9&4H)&9H*3L*("`@("`@
M("`@("`@<')I;G0@)&9H("1F:6QE;F%M92T^>V)U9GT["B`@("`@("`@("`@
M('-E96LH)&9H+"`P+"`P*3L*("`@("`@("`@("`@<F5T=7)N("1F:#L*("`@
M("`@("!]"B`@("`@("`@96QS92!["B`@("`@("`@("`@(&UY("@D;W5T+"`D
M;F%M92D@/2!?=&5M<&9I;&4H)RYP;2<L("1F:6QE;F%M92T^>V-R8WTI.PH@
M("`@("`@("`@("!I9B`H)&]U="D@>PH@("`@("`@("`@("`@("`@8FEN;6]D
M92@D;W5T*3L*("`@("`@("`@("`@("`@('!R:6YT("1O=70@)&9I;&5N86UE
M+3Y[8G5F?3L*("`@("`@("`@("`@("`@(&-L;W-E("1O=70["B`@("`@("`@
M("`@('T*("`@("`@("`@("`@;W!E;B!M>2`D9F@L("<\)RP@)&YA;64@;W(@
M9&EE("0A.PH@("`@("`@("`@("!B:6YM;V1E*"1F:"D["B`@("`@("`@("`@
M(')E='5R;B`D9F@["B`@("`@("`@?0H*("`@("`@("!D:64@(D)O;W1S=')A
M<'!I;F<@9F%I;&5D.B!C86YN;W0@9FEN9"`D;6]D=6QE(5QN(CL*("`@('TL
M($!)3D,I.PH*("`@(",@3F]W(&QO860@86QL(&)U;F1L960@9FEL97,@>WM[
M"@H@("`@(R!I;FET:6%L:7IE('-H87)E9"!O8FIE8W0@<')O8V5S<VEN9PH@
M("`@<F5Q=6ER92!84TQO861E<CL*("`@(')E<75I<F4@4$%2.CI(96%V>3L*
M("`@(')E<75I<F4@0V%R<#HZ2&5A=GD["B`@("!R97%U:7)E($5X<&]R=&5R
M.CI(96%V>3L*("`@(%!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*
M"B`@("`C(&YO=R!L970G<R!T<GD@9V5T=&EN9R!H96QP97(@;6]D=6QE<R!F
M<F]M('=I=&AI;@H@("`@<F5Q=6ER92!)3SHZ1FEL93L*"B`@("`C(&QO860@
M<F5S="!O9B!T:&4@9W)O=7`@:6X*("`@('=H:6QE("AM>2`D9FEL96YA;64@
M/2`H<V]R="!K97ES("5R97%U:7)E7VQI<W0I6S!=*2!["B`@("`@("`@(VQO
M8V%L("1)3D-[)T-W9"YP;2=](#T@7U]&24Q%7U\@:68@)%Y/(&YE("=-4U=I
M;C,R)SL*("`@("`@("!U;FQE<W,@*"1)3D-[)&9I;&5N86UE?2!O<B`D9FEL
M96YA;64@/7X@+T)31%!!3B\I('L*("`@("`@("`@("`@(R!R97%U:7)E(&UO
M9'5L97,L(&1O(&]T:&5R(&5X96-U=&%B;&4@9FEL97,*("`@("`@("`@("`@
M:68@*"1F:6QE;F%M92`]?B`O7"YP;6,_)"]I*2!["B`@("`@("`@("`@("`@
M("!R97%U:7)E("1F:6QE;F%M93L*("`@("`@("`@("`@?0H@("`@("`@("`@
M("!E;'-E('L*("`@("`@("`@("`@("`@(",@4VMI<"!!8W1I=F53=&%T92=S
M('-I=&5C=7-T;VUI>F4N<&P@9FEL93H*("`@("`@("`@("`@("`@(&1O("1F
M:6QE;F%M92!U;FQE<W,@)&9I;&5N86UE(#U^("]S:71E8W5S=&]M:7IE7"YP
M;"0O.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@("`@(&1E;&5T92`D
M<F5Q=6ER95]L:7-T>R1F:6QE;F%M97T["B`@("!]"@H@("`@(R!]?7T*"B`@
M("!L87-T('5N;&5S<R`D8G5F(&5Q(")02UPP,#-<,#`T(CL*("`@("1S=&%R
M=%]P;W,@/2`H=&5L;"!?1D@I("T@-#L*?0HC('U]?0H*(R!!<F=U;65N="!P
M<F]C97-S:6YG('M[>PIM>2!`<&%R7V%R9W,["FUY("@D;W5T+"`D8G5N9&QE
M+"`D;&]G9F@L("1C86-H95]N86UE*3L*"F1E;&5T92`D14Y6>U!!4E]!4%!?
M4D554T5].R`C('-A;FET:7IE("A2155312!M87D@8F4@82!S96-U<FET>2!P
M<F]B;&5M*0H*)'%U:65T(#T@,"!U;FQE<W,@)$5.5GM005)?1$5"54=].PHC
M($1O;B=T('-W86QL;W<@87)G=6UE;G1S(&9O<B!C;VUP:6QE9"!E>&5C=71A
M8FQE<R!W:71H;W5T("TM<&%R+6]P=&EO;G,*:68@*"$D<W1A<G1?<&]S(&]R
M("@D05)'5ELP72!E<2`G+2UP87(M;W!T:6]N<R<@)B8@<VAI9G0I*2!["B`@
M("!M>2`E9&ES=%]C;60@/2!Q=R@*("`@("`@("!P("`@8FQI8E]T;U]P87(*
M("`@("`@("!I("`@:6YS=&%L;%]P87(*("`@("`@("!U("`@=6YI;G-T86QL
M7W!A<@H@("`@("`@(',@("!S:6=N7W!A<@H@("`@("`@('8@("!V97)I9GE?
M<&%R"B`@("`I.PH*("`@(",@:68@=&AE(&%P<"!I<R!I;G9O:V5D(&%S(")A
M<'!N86UE("TM<&%R+6]P=&EO;G,@+2UR975S92!04D]'4D%-($!04D]'7T%2
M1U8B+`H@("`@(R!U<V4@=&AE(&%P<"!T;R!R=6X@=&AE(&=I=F5N('!E<FP@
M8V]D92!I;G-T96%D(&]F(&%N>71H:6YG(&9R;VT@=&AE"B`@("`C(&%P<"!I
M='-E;&8@*&)U="!S=&EL;"!S970@=7`@=&AE(&YO<FUA;"!A<'`@96YV:7)O
M;FUE;G0@86YD($!)3D,I"B`@("!I9B`H0$%21U8@86YD("1!4D=66S!=(&5Q
M("<M+7)E=7-E)RD@>PH@("`@("`@('-H:69T($!!4D=6.PH@("`@("`@("1%
M3E9[4$%27T%04%]2155317T@/2!S:&EF="!`05)'5CL*("`@('T*("`@(&5L
M<V4@>R`C(&YO<FUA;"!P87)L(&)E:&%V:6]U<@H*("`@("`@("!M>2!`861D
M7W1O7VEN8SL*("`@("`@("!W:&EL92`H0$%21U8I('L*("`@("`@("`@("`@
M)$%21U9;,%T@/7X@+UXM*%M!24U/0DQB<7!I=7-4=ETI*"XJ*2\@;W(@;&%S
M=#L*"B`@("`@("`@("`@(&EF("@D,2!E<2`G22<I('L*("`@("`@("`@("`@
M("`@('!U<V@@0&%D9%]T;U]I;F,L("0R.PH@("`@("`@("`@("!]"B`@("`@
M("`@("`@(&5L<VEF("@D,2!E<2`G32<I('L*("`@("`@("`@("`@("`@(&5V
M86P@(G5S92`D,B(["B`@("`@("`@("`@('T*("`@("`@("`@("`@96QS:68@
M*"0Q(&5Q("=!)RD@>PH@("`@("`@("`@("`@("`@=6YS:&EF="!`<&%R7V%R
M9W,L("0R.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&5L<VEF("@D,2!E
M<2`G3R<I('L*("`@("`@("`@("`@("`@("1O=70@/2`D,CL*("`@("`@("`@
M("`@?0H@("`@("`@("`@("!E;'-I9B`H)#$@97$@)V(G*2!["B`@("`@("`@
M("`@("`@("`D8G5N9&QE(#T@)W-I=&4G.PH@("`@("`@("`@("!]"B`@("`@
M("`@("`@(&5L<VEF("@D,2!E<2`G0B<I('L*("`@("`@("`@("`@("`@("1B
M=6YD;&4@/2`G86QL)SL*("`@("`@("`@("`@?0H@("`@("`@("`@("!E;'-I
M9B`H)#$@97$@)W$G*2!["B`@("`@("`@("`@("`@("`D<75I970@/2`Q.PH@
M("`@("`@("`@("!]"B`@("`@("`@("`@(&5L<VEF("@D,2!E<2`G3"<I('L*
M("`@("`@("`@("`@("`@(&]P96X@)&QO9V9H+"`B/CXB+"`D,B!O<B!D:64@
M(EA86#H@0V%N;F]T(&]P96X@;&]G.B`D(2(["B`@("`@("`@("`@('T*("`@
M("`@("`@("`@96QS:68@*"0Q(&5Q("=4)RD@>PH@("`@("`@("`@("`@("`@
M)&-A8VAE7VYA;64@/2`D,CL*("`@("`@("`@("`@?0H*("`@("`@("`@("`@
M<VAI9G0H0$%21U8I.PH*("`@("`@("`@("`@:68@*&UY("1C;60@/2`D9&ES
M=%]C;61[)#%]*2!["B`@("`@("`@("`@("`@("!D96QE=&4@)$5.5GLG4$%2
M7U1%35`G?3L*("`@("`@("`@("`@("`@(&EN:71?:6YC*"D["B`@("`@("`@
M("`@("`@("!R97%U:7)E(%!!4CHZ1&ES=#L*("`@("`@("`@("`@("`@("9[
M(E!!4CHZ1&ES=#HZ)&-M9")]*"D@=6YL97-S($!!4D=6.PH@("`@("`@("`@
M("`@("`@)GLB4$%2.CI$:7-T.CHD8VUD(GTH)%\I(&9O<B!`05)'5CL*("`@
M("`@("`@("`@("`@(&5X:70["B`@("`@("`@("`@('T*("`@("`@("!]"@H@
M("`@("`@('5N<VAI9G0@0$E.0RP@0&%D9%]T;U]I;F,["B`@("!]"GT*"B,@
M6%A8("TM(&%D9"`M+7!A<BUD96)U9R!S=7!P;W)T(0H*(R!]?7T*"B,@3W5T
M<'5T(&UO9&4@*"U/*2!H86YD;&EN9R![>WL*:68@*"1O=70I('L*("`@('L*
M("`@("`@("`C;&]C86P@)$E.0WLG0W=D+G!M)WT@/2!?7T9)3$5?7R!I9B`D
M7D\@;F4@)TU35VEN,S(G.PH@("`@("`@(')E<75I<F4@24\Z.D9I;&4["B`@
M("`@("`@<F5Q=6ER92!!<F-H:79E.CI::7`["B`@("!]"@H@("`@;7D@)'!A
M<B`]('-H:69T*$!!4D=6*3L*("`@(&UY("1Z:7`["@H*("`@(&EF("AD969I
M;F5D("1P87(I('L*("`@("`@("!O<&5N(&UY("1F:"P@)SPG+"`D<&%R(&]R
M(&1I92`B0V%N;F]T(&9I;F0@)R1P87(G.B`D(2(["B`@("`@("`@8FEN;6]D
M92@D9F@I.PH@("`@("`@(&)L97-S*"1F:"P@)TE/.CI&:6QE)RD["@H@("`@
M("`@("1Z:7`@/2!!<F-H:79E.CI::7`M/FYE=SL*("`@("`@("`H("1Z:7`M
M/G)E861&<F]M1FEL94AA;F1L92@D9F@L("1P87(I(#T]($%R8VAI=F4Z.EII
M<#HZ05I?3TLH*2`I"B`@("`@("`@("`@(&]R(&1I92`B4F5A9"`G)'!A<B<@
M97)R;W(Z("0A(CL*("`@('T*"@H@("`@;7D@)65N=B`](&1O('L*("`@("`@
M("!I9B`H)'II<"!A;F0@;7D@)&UE=&$@/2`D>FEP+3YC;VYT96YT<R@G3454
M02YY;6PG*2D@>PH@("`@("`@("`@("`D;65T82`]?B!S+RXJ7G!A<CHD+R]M
M<SL*("`@("`@("`@("`@)&UE=&$@/7X@<R]>7%,N*B\O;7,["B`@("`@("`@
M("`@("1M971A(#U^("]>("`H6UXZ72LI.B`H+BLI)"]M9SL*("`@("`@("!]
M"B`@("!].PH*("`@(",@3W!E;B!I;G!U="!A;F0@;W5T<'5T(&9I;&5S('M[
M>PH@("`@;&]C86P@)"\@/2!<-#L*"B`@("!I9B`H9&5F:6YE9"`D<&%R*2![
M"B`@("`@("`@;W!E;B!005(L("<\)RP@)'!A<B!O<B!D:64@(B0A.B`D<&%R
M(CL*("`@("`@("!B:6YM;V1E*%!!4BD["B`@("`@("`@9&EE("(D<&%R(&ES
M(&YO="!A(%!!4B!F:6QE(B!U;FQE<W,@/%!!4CX@97$@(E!+7#`P,UPP,#0B
M.PH@("`@?0H*("`@($-R96%T95!A=&@H)&]U="D@.PH@("`@"B`@("!M>2`D
M9F@@/2!)3SHZ1FEL92T^;F5W*`H@("`@("`@("1O=70L"B`@("`@("`@24\Z
M.D9I;&4Z.D]?0U)%050H*2!\($E/.CI&:6QE.CI/7U=23TY,62@I('P@24\Z
M.D9I;&4Z.D]?5%)53D,H*2P*("`@("`@("`P-S<W+`H@("`@*2!O<B!D:64@
M)"$["B`@("!B:6YM;V1E*"1F:"D["@H@("`@)"\@/2`H9&5F:6YE9"`D9&%T
M85]P;W,I(#\@7"1D871A7W!O<R`Z('5N9&5F.PH@("`@<V5E:R!?1D@L(#`L
M(#`["B`@("!M>2`D;&]A9&5R(#T@<V-A;&%R(#Q?1D@^.PH@("`@:68@*"$D
M14Y6>U!!4E]615)"051)37T@86YD("1L;V%D97(@/7X@+UXH/SHC(7Q<0')E
M;2DO*2!["B`@("`@("`@<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&]D4W1R:7`[
M"B`@("`@("`@4$%2.CI&:6QT97(Z.E!O9%-T<FEP+3YN97<M/F%P<&QY*%PD
M;&]A9&5R+"`D,"D*("`@('T*("`@(&9O<F5A8V@@;7D@)&ME>2`H<V]R="!K
M97ES("5E;G8I('L*("`@("`@("!M>2`D=F%L(#T@)&5N=GLD:V5Y?2!O<B!N
M97AT.PH@("`@("`@("1V86P@/2!E=F%L("1V86P@:68@)'9A;"`]?B`O7ELG
M(ETO.PH@("`@("`@(&UY("1M86=I8R`](")?7T5.5E]005)?(B`N('5C*"1K
M97DI("X@(E]?(CL*("`@("`@("!M>2`D<V5T(#T@(E!!4E\B("X@=6,H)&ME
M>2D@+B`B/21V86PB.PH@("`@("`@("1L;V%D97(@/7X@<WLD;6%G:6,H("LI
M?7L*("`@("`@("`@("`@)&UA9VEC("X@)'-E="`N("@G("<@>"`H;&5N9W1H
M*"0Q*2`M(&QE;F=T:"@D<V5T*2DI"B`@("`@("`@?65G.PH@("`@?0H@("`@
M)&9H+3YP<FEN="@D;&]A9&5R*3L*("`@("0O(#T@=6YD968["B`@("`C('U]
M?0H*("`@(",@5W)I=&4@8G5N9&QE9"!M;V1U;&5S('M[>PH@("`@:68@*"1B
M=6YD;&4I('L*("`@("`@("!R97%U:7)E(%!!4CHZ2&5A=GD["B`@("`@("`@
M4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PH@("`@("`@(&EN:71?
M:6YC*"D["@H@("`@("`@(')E<75I<F5?;6]D=6QE<R@I.PH*("`@("`@("!M
M>2!`:6YC(#T@<V]R="!["B`@("`@("`@("`@(&QE;F=T:"@D8BD@/#T^(&QE
M;F=T:"@D82D*("`@("`@("!](&=R97`@>PH@("`@("`@("`@("`A+T)31%!!
M3B\*("`@("`@("!](&=R97`@>PH@("`@("`@("`@("`H)&)U;F1L92!N92`G
M<VET92<I(&]R"B`@("`@("`@("`@("@D7R!N92`D0V]N9FEG.CI#;VYF:6=[
M87)C:&QI8F5X<'T@86YD"B`@("`@("`@("`@("`D7R!N92`D0V]N9FEG.CI#
M;VYF:6=[<')I=FQI8F5X<'TI.PH@("`@("`@('T@0$E.0SL*"B`@("`@("`@
M(R!&:6QE(&5X:7-T<R!T97-T(&%D9&5D('1O(&9I>"!25"`C-#$W.3`Z"B`@
M("`@("`@(R!&=6YN>2P@;F]N+65X:7-T:6YG(&5N=')Y(&EN(%\\+BXN+F%U
M=&\O0V]M<')E<W,O4F%W+UIL:6(O875T;W-P;&ET+FEX+@H@("`@("`@(",@
M5&AI<R!I<R!A(&)A;F0M86ED(&9I>"!W:71H(&YO(&1E97!E<B!G<F%S<"!O
M9B!T:&4@:7-S=64N"B`@("`@("`@(R!3;VUE8F]D>2!P;&5A<V4@9V\@=&AR
M;W5G:"!T:&4@<&%I;B!O9B!U;F1E<G-T86YD:6YG('=H870G<R!H87!P96YI
M;F<L"B`@("`@("`@(R!)(&9A:6QE9"X@+2T@4W1E9F9E;@H@("`@("`@(&UY
M("5F:6QE<SL*("`@("`@("`O7E\\*"XK*20O(&%N9"`M92`D,2!A;F0@)&9I
M;&5S>R0Q?2LK(&9O<B!K97ES("4Z.CL*("`@("`@("`D9FEL97-[)%]]*RL@
M9F]R('9A;'5E<R`E24Y#.PH*("`@("`@("!M>2`D;&EB7V5X="`]("1#;VYF
M:6<Z.D-O;F9I9WML:6)?97AT?3L*("`@("`@("!M>2`E=W)I='1E;CL*"B`@
M("`@("`@9F]R96%C:"`H<V]R="!K97ES("5F:6QE<RD@>PH@("`@("`@("`@
M("!M>2`H)&YA;64L("1F:6QE*3L*"B`@("`@("`@("`@(&9O<F5A8V@@;7D@
M)&1I<B`H0&EN8RD@>PH@("`@("`@("`@("`@("`@:68@*"1N86UE(#T@)%!!
M4CHZ2&5A=GDZ.D9U;&Q#86-H97LD7WTI('L*("`@("`@("`@("`@("`@("`@
M("`D9FEL92`]("1?.PH@("`@("`@("`@("`@("`@("`@(&QA<W0["B`@("`@
M("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!E;'-I9B`H+UXH7%$D9&ER
M7$5<+R@N*EM>0V-=*2E<6B]I*2!["B`@("`@("`@("`@("`@("`@("`@*"1F
M:6QE+"`D;F%M92D@/2`H)#$L("0R*3L*("`@("`@("`@("`@("`@("`@("!L
M87-T.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@96QS:68@
M*&TA7B]L;V%D97(O6UXO72LO*"XJ6UY#8UTI7%HA*2!["B`@("`@("`@("`@
M("`@("`@("`@:68@*&UY("1R968@/2`D4$%2.CI(96%V>3HZ36]D=6QE0V%C
M:&5[)#%]*2!["B`@("`@("`@("`@("`@("`@("`@("`@("@D9FEL92P@)&YA
M;64I(#T@*"1R968L("0Q*3L*("`@("`@("`@("`@("`@("`@("`@("`@;&%S
M=#L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("`@("`@
M96QS:68@*"UF("(D9&ER+R0Q(BD@>PH@("`@("`@("`@("`@("`@("`@("`@
M("`H)&9I;&4L("1N86UE*2`]("@B)&1I<B\D,2(L("0Q*3L*("`@("`@("`@
M("`@("`@("`@("`@("`@;&%S=#L*("`@("`@("`@("`@("`@("`@("!]"B`@
M("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*"B`@("`@("`@("`@(&YE
M>'0@=6YL97-S(&1E9FEN960@)&YA;64@86YD(&YO="`D=W)I='1E;GLD;F%M
M97TK*SL*("`@("`@("`@("`@;F5X="!I9B`A<F5F*"1F:6QE*2!A;F0@)&9I
M;&4@/7X@+UPN7%$D;&EB7V5X=%Q%)"\["B`@("`@("`@("`@(&]U=',H(&IO
M:6X@(B(L"B`@("`@("`@("`@("`@("!Q<2A086-K:6YG("(I+"!R968@)&9I
M;&4@/R`D9FEL92T^>VYA;65](#H@)&9I;&4L"B`@("`@("`@("`@("`@("!Q
M<2@B+BXN*0H@("`@("`@("`@("`I.PH*("`@("`@("`@("`@;7D@)&-O;G1E
M;G0["B`@("`@("`@("`@(&EF("AR968H)&9I;&4I*2!["B`@("`@("`@("`@
M("`@("`D8V]N=&5N="`]("1F:6QE+3Y[8G5F?3L*("`@("`@("`@("`@?0H@
M("`@("`@("`@("!E;'-E('L*("`@("`@("`@("`@("`@(&]P96X@1DE,12P@
M)SPG+"`D9FEL92!O<B!D:64@(D-A;B=T(&]P96X@)&9I;&4Z("0A(CL*("`@
M("`@("`@("`@("`@(&)I;FUO9&4H1DE,12D["B`@("`@("`@("`@("`@("`D
M8V]N=&5N="`](#Q&24Q%/CL*("`@("`@("`@("`@("`@(&-L;W-E($9)3$4[
M"@H@("`@("`@("`@("`@("`@4$%2.CI&:6QT97(Z.E!O9%-T<FEP+3YN97<M
M/F%P<&QY*%PD8V]N=&5N="P@)&9I;&4I"B`@("`@("`@("`@("`@("`@("`@
M:68@(21%3E9[4$%27U9%4D)!5$E-?2!A;F0@)&YA;64@/7X@+UPN*#\Z<&U\
M:7A\86PI)"]I.PH*("`@("`@("`@("`@("`@(%!!4CHZ1FEL=&5R.CI0871C
M:$-O;G1E;G0M/FYE=RT^87!P;'DH7"1C;VYT96YT+"`D9FEL92P@)&YA;64I
M.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("!O=71S*'%Q*%=R:71T96X@
M87,@(B1N86UE(BDI.PH@("`@("`@("`@("`D9F@M/G!R:6YT*")&24Q%(BD[
M"B`@("`@("`@("`@("1F:"T^<')I;G0H<&%C:R@G3B<L(&QE;F=T:"@D;F%M
M92D@*R`Y*2D["B`@("`@("`@("`@("1F:"T^<')I;G0H<W!R:6YT9B@*("`@
M("`@("`@("`@("`@("(E,#AX+R5S(BP@07)C:&EV93HZ6FEP.CIC;VUP=71E
M0U)#,S(H)&-O;G1E;G0I+"`D;F%M90H@("`@("`@("`@("`I*3L*("`@("`@
M("`@("`@)&9H+3YP<FEN="AP86-K*"=.)RP@;&5N9W1H*"1C;VYT96YT*2DI
M.PH@("`@("`@("`@("`D9F@M/G!R:6YT*"1C;VYT96YT*3L*("`@("`@("!]
M"B`@("!]"B`@("`C('U]?0H*("`@(",@3F]W('=R:71E(&]U="!T:&4@4$%2
M(&%N9"!M86=I8R!S=')I;F=S('M[>PH@("`@)'II<"T^=W)I=&54;T9I;&5(
M86YD;&4H)&9H*2!I9B`D>FEP.PH*("`@("1C86-H95]N86UE(#T@<W5B<W1R
M("1C86-H95]N86UE+"`P+"`T,#L*("`@(&EF("@A)&-A8VAE7VYA;64@86YD
M(&UY("1M=&EM92`]("AS=&%T*"1O=70I*5LY72D@>PH@("`@("`@(&UY("1C
M='@@/2!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.E-(03L@1&EG97-T.CI32$$M
M/FYE=R@Q*2!]"B`@("`@("`@("`@('Q\(&5V86P@>R!R97%U:7)E($1I9V5S
M=#HZ4TA!,3L@1&EG97-T.CI32$$Q+3YN97<@?0H@("`@("`@("`@("!\?"!E
M=F%L('L@<F5Q=6ER92!$:6=E<W0Z.DU$-3L@1&EG97-T.CI-1#4M/FYE=R!]
M.PH*("`@("`@("`C(%=O<FMA<F]U;F0@9F]R(&)U9R!I;B!$:6=E<W0Z.E-(
M02`U+C,X(&%N9"`U+C,Y"B`@("`@("`@;7D@)'-H85]V97)S:6]N(#T@979A
M;"![("1$:6=E<W0Z.E-(03HZ5D524TE/3B!]('Q\(#`["B`@("`@("`@:68@
M*"1S:&%?=F5R<VEO;B!E<2`G-2XS."<@;W(@)'-H85]V97)S:6]N(&5Q("<U
M+C,Y)RD@>PH@("`@("`@("`@("`D8W1X+3YA9&1F:6QE*"1O=70L(")B(BD@
M:68@*"1C='@I.PH@("`@("`@('T*("`@("`@("!E;'-E('L*("`@("`@("`@
M("`@:68@*"1C='@@86YD(&]P96XH;7D@)&9H+"`B/"1O=70B*2D@>PH@("`@
M("`@("`@("`@("`@8FEN;6]D92@D9F@I.PH@("`@("`@("`@("`@("`@)&-T
M>"T^861D9FEL92@D9F@I.PH@("`@("`@("`@("`@("`@8VQO<V4H)&9H*3L*
M("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@)&-A8VAE7VYA;64@
M/2`D8W1X(#\@)&-T>"T^:&5X9&EG97-T(#H@)&UT:6UE.PH@("`@?0H@("`@
M)&-A8VAE7VYA;64@+CT@(EPP(B!X("@T,2`M(&QE;F=T:"`D8V%C:&5?;F%M
M92D["B`@("`D8V%C:&5?;F%M92`N/2`B0T%#2$4B.PH@("`@)&9H+3YP<FEN
M="@D8V%C:&5?;F%M92D["B`@("`D9F@M/G!R:6YT*'!A8VLH)TXG+"`D9F@M
M/G1E;&P@+2!L96YG=&@H)&QO861E<BDI*3L*("`@("1F:"T^<')I;G0H(EQN
M4$%2+G!M7&XB*3L*("`@("1F:"T^8VQO<V4["B`@("!C:&UO9"`P-S4U+"`D
M;W5T.PH@("`@(R!]?7T*"B`@("!E>&ET.PI]"B,@?7U]"@HC(%!R97!A<F4@
M)'!R;V=N86UE(&EN=&\@4$%2(&9I;&4@8V%C:&4@>WM["GL*("`@(&QA<W0@
M=6YL97-S(&1E9FEN960@)'-T87)T7W!O<SL*"B`@("!?9FEX7W!R;V=N86UE
M*"D["@H@("`@(R!.;W<@;&]A9"!T:&4@4$%2(&9I;&4@86YD('!U="!I="!I
M;G1O(%!!4CHZ3&EB0V%C:&4@>WM["B`@("!R97%U:7)E(%!!4CL*("`@(%!!
M4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*"@H@("`@>PH@("`@("`@
M("-L;V-A;"`D24Y#>R=#=V0N<&TG?2`](%]?1DE,15]?(&EF("1>3R!N92`G
M35-7:6XS,B<["B`@("`@("`@<F5Q=6ER92!&:6QE.CI&:6YD.PH@("`@("`@
M(')E<75I<F4@07)C:&EV93HZ6FEP.PH@("`@?0H@("`@;7D@)'II<"`]($%R
M8VAI=F4Z.EII<"T^;F5W.PH@("`@;7D@)&9H(#T@24\Z.D9I;&4M/FYE=SL*
M("`@("1F:"T^9F1O<&5N*&9I;&5N;RA?1D@I+"`G<B<I(&]R(&1I92`B)"$Z
M("1`(CL*("`@("1Z:7`M/G)E861&<F]M1FEL94AA;F1L92@D9F@L("1P<F]G
M;F%M92D@/3T@07)C:&EV93HZ6FEP.CI!6E]/2R@I(&]R(&1I92`B)"$Z("1`
M(CL*"B`@("!P=7-H($!005(Z.DQI8D-A8VAE+"`D>FEP.PH@("`@)%!!4CHZ
M3&EB0V%C:&5[)'!R;V=N86UE?2`]("1Z:7`["@H@("`@)'%U:65T(#T@(21%
M3E9[4$%27T1%0E5'?3L*("`@(&]U=',H<7$H7"1%3E9[4$%27U1%35!](#T@
M(B1%3E9[4$%27U1%35!](BDI.PH*("`@(&EF("AD969I;F5D("1%3E9[4$%2
M7U1%35!]*2![(",@<VAO=6QD(&)E('-E="!A="!T:&ES('!O:6YT(0H@("`@
M("`@(&9O<F5A8V@@;7D@)&UE;6)E<B`H("1Z:7`M/FUE;6)E<G,@*2!["B`@
M("`@("`@("`@(&YE>'0@:68@)&UE;6)E<BT^:7-$:7)E8W1O<GD["B`@("`@
M("`@("`@(&UY("1M96UB97)?;F%M92`]("1M96UB97(M/F9I;&5.86UE.PH@
M("`@("`@("`@("!N97AT('5N;&5S<R`D;65M8F5R7VYA;64@/7X@;7L*("`@
M("`@("`@("`@("`@(%X*("`@("`@("`@("`@("`@("\_<VAL:6(O"B`@("`@
M("`@("`@("`@("`H/SHD0V]N9FEG.CI#;VYF:6=[=F5R<VEO;GTO*3\*("`@
M("`@("`@("`@("`@("@_.B1#;VYF:6<Z.D-O;F9I9WMA<F-H;F%M97TO*3\*
M("`@("`@("`@("`@("`@("A;7B]=*RD*("`@("`@("`@("`@("`@("0*("`@
M("`@("`@("`@?7@["B`@("`@("`@("`@(&UY("1E>'1R86-T7VYA;64@/2`D
M,3L*("`@("`@("`@("`@;7D@)&1E<W1?;F%M92`]($9I;&4Z.E-P96,M/F-A
M=&9I;&4H)$5.5GM005)?5$5-4'TL("1E>'1R86-T7VYA;64I.PH@("`@("`@
M("`@("!I9B`H+68@)&1E<W1?;F%M92`F)B`M<R!?(#T]("1M96UB97(M/G5N
M8V]M<')E<W-E9%-I>F4H*2D@>PH@("`@("`@("`@("`@("`@;W5T<RAQ<2A3
M:VEP<&EN9R`B)&UE;6)E<E]N86UE(B!S:6YC92!I="!A;')E861Y(&5X:7-T
M<R!A="`B)&1E<W1?;F%M92(I*3L*("`@("`@("`@("`@?2!E;'-E('L*("`@
M("`@("`@("`@("`@(&]U=',H<7$H17AT<F%C=&EN9R`B)&UE;6)E<E]N86UE
M(B!T;R`B)&1E<W1?;F%M92(I*3L*("`@("`@("`@("`@("`@("1M96UB97(M
M/F5X=')A8W14;T9I;&5.86UE9"@D9&5S=%]N86UE*3L*("`@("`@("`@("`@
M("`@(&-H;6]D*#`U-34L("1D97-T7VYA;64I(&EF("1>3R!E<2`B:'!U>"([
M"B`@("`@("`@("`@('T*("`@("`@("!]"B`@("!]"B`@("`C('U]?0I]"B,@
M?7U]"@HC($EF('1H97)E)W,@;F\@;6%I;BYP;"!T;R!R=6XL('-H;W<@=7-A
M9V4@>WM["G5N;&5S<R`H)%!!4CHZ3&EB0V%C:&5[)'!R;V=N86UE?2D@>PH@
M("`@9&EE(#P\("(N(B!U;FQE<W,@0$%21U8["E5S86=E.B`D,"!;("U!;&EB
M+G!A<B!=(%L@+4ED:7(@72!;("U-;6]D=6QE(%T@6R!S<F,N<&%R(%T@6R!P
M<F]G<F%M+G!L(%T*("`@("`@("0P(%L@+4)\+6(@72!;+4]O=71F:6QE72!S
M<F,N<&%R"BX*("`@("1%3E9[4$%27U!23T=.04U%?2`]("1P<F]G;F%M92`]
M("0P(#T@<VAI9G0H0$%21U8I.PI]"B,@?7U]"@IS=6(@0W)E871E4&%T:"![
M"B`@("!M>2`H)&YA;64I(#T@0%\["B`@("`*("`@(')E<75I<F4@1FEL93HZ
M0F%S96YA;64["B`@("!M>2`H)&)A<V5N86UE+"`D<&%T:"P@)&5X="D@/2!&
M:6QE.CI"87-E;F%M93HZ9FEL97!A<G-E*"1N86UE+"`H)UPN+BHG*2D["B`@
M("`*("`@(')E<75I<F4@1FEL93HZ4&%T:#L*("`@(`H@("`@1FEL93HZ4&%T
M:#HZ;6MP871H*"1P871H*2!U;FQE<W,H+64@)'!A=&@I.R`C(&UK<&%T:"!D
M:65S('=I=&@@97)R;W(*?0H*<W5B(')E<75I<F5?;6]D=6QE<R!["B`@("`C
M;&]C86P@)$E.0WLG0W=D+G!M)WT@/2!?7T9)3$5?7R!I9B`D7D\@;F4@)TU3
M5VEN,S(G.PH*("`@(')E<75I<F4@;&EB.PH@("`@<F5Q=6ER92!$>6YA3&]A
M9&5R.PH@("`@<F5Q=6ER92!I;G1E9V5R.PH@("`@<F5Q=6ER92!S=')I8W0[
M"B`@("!R97%U:7)E('=A<FYI;F=S.PH@("`@<F5Q=6ER92!V87)S.PH@("`@
M<F5Q=6ER92!#87)P.PH@("`@<F5Q=6ER92!#87)P.CI(96%V>3L*("`@(')E
M<75I<F4@17)R;F\["B`@("!R97%U:7)E($5X<&]R=&5R.CI(96%V>3L*("`@
M(')E<75I<F4@17AP;W)T97(["B`@("!R97%U:7)E($9C;G1L.PH@("`@<F5Q
M=6ER92!&:6QE.CI496UP.PH@("`@<F5Q=6ER92!&:6QE.CI3<&5C.PH@("`@
M<F5Q=6ER92!84TQO861E<CL*("`@(')E<75I<F4@0V]N9FEG.PH@("`@<F5Q
M=6ER92!)3SHZ2&%N9&QE.PH@("`@<F5Q=6ER92!)3SHZ1FEL93L*("`@(')E
M<75I<F4@0V]M<')E<W,Z.EIL:6(["B`@("!R97%U:7)E($%R8VAI=F4Z.EII
M<#L*("`@(')E<75I<F4@4$%2.PH@("`@<F5Q=6ER92!005(Z.DAE879Y.PH@
M("`@<F5Q=6ER92!005(Z.D1I<W0["B`@("!R97%U:7)E(%!!4CHZ1FEL=&5R
M.CI0;V13=')I<#L*("`@(')E<75I<F4@4$%2.CI&:6QT97(Z.E!A=&-H0V]N
M=&5N=#L*("`@(')E<75I<F4@871T<FEB=71E<SL*("`@(&5V86P@>R!R97%U
M:7)E($-W9"!].PH@("`@979A;"![(')E<75I<F4@5VEN,S(@?3L*("`@(&5V
M86P@>R!R97%U:7)E(%-C86QA<CHZ571I;"!].PH@("`@979A;"![(')E<75I
M<F4@07)C:&EV93HZ56YZ:7`Z.D)U<G-T('T["B`@("!E=F%L('L@<F5Q=6ER
M92!4:64Z.DAA<V@Z.DYA;65D0V%P='5R92!].PH@("`@979A;"![(')E<75I
M<F4@4&5R;$E/.R!R97%U:7)E(%!E<FQ)3SHZ<V-A;&%R('T["GT*"B,@5&AE
M($,@=F5R<VEO;B!O9B!T:&ES(&-O9&4@87!P96%R<R!I;B!M>6QD<B]M:W1M
M<&1I<BYC"B,@5&AI<R!C;V1E(&%L<V\@;&EV97,@:6X@4$%2.CI3971U<%1E
M;7`@87,@<V5T7W!A<E]T96UP7V5N=B$*<W5B(%]S971?<&%R7W1E;7`@>PH@
M("`@:68@*&1E9FEN960@)$5.5GM005)?5$5-4'T@86YD("1%3E9[4$%27U1%
M35!](#U^("\H+BLI+RD@>PH@("`@("`@("1P87)?=&5M<"`]("0Q.PH@("`@
M("`@(')E='5R;CL*("`@('T*"B`@("!F;W)E86-H(&UY("1P871H("@*("`@
M("`@("`H;6%P("1%3E9[)%]]+"!Q=R@@4$%27U1-4$1)4B!435!$25(@5$5-
M4$1)4B!414U0(%1-4"`I*2P*("`@("`@("!Q=R@@0SI<7%1%35`@+W1M<"`N
M("D*("`@("D@>PH@("`@("`@(&YE>'0@=6YL97-S(&1E9FEN960@)'!A=&@@
M86YD("UD("1P871H(&%N9"`M=R`D<&%T:#L*("`@("`@("!M>2`D=7-E<FYA
M;64["B`@("`@("`@;7D@)'!W=6ED.PH@("`@("`@(",@9&]E<R!N;W0@=V]R
M:R!E=F5R>7=H97)E.@H@("`@("`@(&5V86P@>R@D<'=U:60I(#T@9V5T<'=U
M:60H)#XI(&EF(&1E9FEN960@)#X[?3L*"B`@("`@("`@:68@*"!D969I;F5D
M*"97:6XS,CHZ3&]G:6Y.86UE*2`I('L*("`@("`@("`@("`@)'5S97)N86UE
M(#T@)E=I;C,R.CI,;V=I;DYA;64["B`@("`@("`@?0H@("`@("`@(&5L<VEF
M("AD969I;F5D("1P=W5I9"D@>PH@("`@("`@("`@("`D=7-E<FYA;64@/2`D
M<'=U:60["B`@("`@("`@?0H@("`@("`@(&5L<V4@>PH@("`@("`@("`@("`D
M=7-E<FYA;64@/2`D14Y6>U5315).04U%?2!\?"`D14Y6>U5315)]('Q\("=3
M65-414TG.PH@("`@("`@('T*("`@("`@("`D=7-E<FYA;64@/7X@<R]<5R]?
M+V<["@H@("`@("`@(&UY("1S=&UP9&ER(#T@(B1P871H)$-O;F9I9WM?9&5L
M:6U]<&%R+21U<V5R;F%M92(["B`@("`@("`@;6MD:7(@)'-T;7!D:7(L(#`W
M-34["B`@("`@("`@:68@*"$D14Y6>U!!4E]#3$5!3GT@86YD(&UY("1M=&EM
M92`]("AS=&%T*"1P<F]G;F%M92DI6SE=*2!["B`@("`@("`@("`@(&]P96X@
M*&UY("1F:"P@(CPB+B`D<')O9VYA;64I.PH@("`@("`@("`@("!S965K("1F
M:"P@+3$X+"`R.PH@("`@("`@("`@("!S>7-R96%D("1F:"P@;7D@)&)U9BP@
M-CL*("`@("`@("`@("`@:68@*"1B=68@97$@(EPP0T%#2$4B*2!["B`@("`@
M("`@("`@("`@("!S965K("1F:"P@+34X+"`R.PH@("`@("`@("`@("`@("`@
M<WES<F5A9"`D9F@L("1B=68L(#0Q.PH@("`@("`@("`@("`@("`@)&)U9B`]
M?B!S+UPP+R]G.PH@("`@("`@("`@("`@("`@)'-T;7!D:7(@+CT@(B1#;VYF
M:6=[7V1E;&EM?6-A8VAE+2(@+B`D8G5F.PH@("`@("`@("`@("!]"B`@("`@
M("`@("`@(&5L<V4@>PH@("`@("`@("`@("`@("`@;7D@)&-T>"`](&5V86P@
M>R!R97%U:7)E($1I9V5S=#HZ4TA!.R!$:6=E<W0Z.E-(02T^;F5W*#$I('T*
M("`@("`@("`@("`@("`@("`@("!\?"!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z
M.E-(03$[($1I9V5S=#HZ4TA!,2T^;F5W('T*("`@("`@("`@("`@("`@("`@
M("!\?"!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.DU$-3L@1&EG97-T.CI-1#4M
M/FYE=R!].PH*("`@("`@("`@("`@("`@(",@5V]R:V%R;W5N9"!F;W(@8G5G
M(&EN($1I9V5S=#HZ4TA!(#4N,S@@86YD(#4N,SD*("`@("`@("`@("`@("`@
M(&UY("1S:&%?=F5R<VEO;B`](&5V86P@>R`D1&EG97-T.CI32$$Z.E9%4E-)
M3TX@?2!\?"`P.PH@("`@("`@("`@("`@("`@:68@*"1S:&%?=F5R<VEO;B!E
M<2`G-2XS."<@;W(@)'-H85]V97)S:6]N(&5Q("<U+C,Y)RD@>PH@("`@("`@
M("`@("`@("`@("`@("1C='@M/F%D9&9I;&4H)'!R;V=N86UE+"`B8B(I(&EF
M("@D8W1X*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@(&5L
M<V4@>PH@("`@("`@("`@("`@("`@("`@(&EF("@D8W1X(&%N9"!O<&5N*&UY
M("1F:"P@(CPD<')O9VYA;64B*2D@>PH@("`@("`@("`@("`@("`@("`@("`@
M("!B:6YM;V1E*"1F:"D["B`@("`@("`@("`@("`@("`@("`@("`@("1C='@M
M/F%D9&9I;&4H)&9H*3L*("`@("`@("`@("`@("`@("`@("`@("`@8VQO<V4H
M)&9H*3L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!]
M"@H@("`@("`@("`@("`@("`@)'-T;7!D:7(@+CT@(B1#;VYF:6=[7V1E;&EM
M?6-A8VAE+2(@+B`H("1C='@@/R`D8W1X+3YH97AD:6=E<W0@.B`D;71I;64@
M*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("!C;&]S92@D9F@I.PH@("`@
M("`@('T*("`@("`@("!E;'-E('L*("`@("`@("`@("`@)$5.5GM005)?0TQ%
M04Y](#T@,3L*("`@("`@("`@("`@)'-T;7!D:7(@+CT@(B1#;VYF:6=[7V1E
M;&EM?71E;7`M)"0B.PH@("`@("`@('T*"B`@("`@("`@)$5.5GM005)?5$5-
M4'T@/2`D<W1M<&1I<CL*("`@("`@("!M:V1I<B`D<W1M<&1I<BP@,#<U-3L*
M("`@("`@("!L87-T.PH@("`@?0H*("`@("1P87)?=&5M<"`]("0Q(&EF("1%
M3E9[4$%27U1%35!](&%N9"`D14Y6>U!!4E]414U0?2`]?B`O*"XK*2\["GT*
M"G-U8B!?=&5M<&9I;&4@>PH@("`@;7D@*"1E>'0L("1C<F,I(#T@0%\["B`@
M("!M>2`H)&9H+"`D9FEL96YA;64I.PH*("`@("1F:6QE;F%M92`]("(D<&%R
M7W1E;7`O)&-R8R1E>'0B.PH*("`@(&EF("@D14Y6>U!!4E]#3$5!3GTI('L*
M("`@("`@("!U;FQI;FL@)&9I;&5N86UE(&EF("UE("1F:6QE;F%M93L*("`@
M("`@("!P=7-H($!T;7!F:6QE+"`D9FEL96YA;64["B`@("!]"B`@("!E;'-E
M('L*("`@("`@("!R971U<FX@*'5N9&5F+"`D9FEL96YA;64I(&EF("@M<B`D
M9FEL96YA;64I.PH@("`@?0H*("`@(&]P96X@)&9H+"`G/B<L("1F:6QE;F%M
M92!O<B!D:64@)"$["B`@("!B:6YM;V1E*"1F:"D["B`@("!R971U<FXH)&9H
M+"`D9FEL96YA;64I.PI]"@HC('-A;64@8V]D92!L:79E<R!I;B!005(Z.E-E
M='5P4')O9VYA;64Z.G-E=%]P<F]G;F%M90IS=6(@7W-E=%]P<F]G;F%M92![
M"B`@("!I9B`H9&5F:6YE9"`D14Y6>U!!4E]04D]'3D%-17T@86YD("1%3E9[
M4$%27U!23T=.04U%?2`]?B`O*"XK*2\I('L*("`@("`@("`D<')O9VYA;64@
M/2`D,3L*("`@('T*"B`@("`D<')O9VYA;64@?'P]("0P.PH*("`@(&EF("@D
M14Y6>U!!4E]414U0?2!A;F0@:6YD97@H)'!R;V=N86UE+"`D14Y6>U!!4E]4
M14U0?2D@/CT@,"D@>PH@("`@("`@("1P<F]G;F%M92`]('-U8G-T<B@D<')O
M9VYA;64L(')I;F1E>"@D<')O9VYA;64L("1#;VYF:6=[7V1E;&EM?2D@*R`Q
M*3L*("`@('T*"B`@("!I9B`H(21%3E9[4$%27U!23T=.04U%?2!O<B!I;F1E
M>"@D<')O9VYA;64L("1#;VYF:6=[7V1E;&EM?2D@/CT@,"D@>PH@("`@("`@
M(&EF("AO<&5N(&UY("1F:"P@)SPG+"`D<')O9VYA;64I('L*("`@("`@("`@
M("`@<F5T=7)N(&EF("US("1F:#L*("`@("`@("!]"B`@("`@("`@:68@*"US
M("(D<')O9VYA;64D0V]N9FEG>U]E>&5](BD@>PH@("`@("`@("`@("`D<')O
M9VYA;64@+CT@)$-O;F9I9WM?97AE?3L*("`@("`@("`@("`@<F5T=7)N.PH@
M("`@("`@('T*("`@('T*"B`@("!F;W)E86-H(&UY("1D:7(@*'-P;&ET("]<
M421#;VYF:6=[<&%T:%]S97!]7$4O+"`D14Y6>U!!5$A]*2!["B`@("`@("`@
M;F5X="!I9B!E>&ES=',@)$5.5GM005)?5$5-4'T@86YD("1D:7(@97$@)$5.
M5GM005)?5$5-4'T["B`@("`@("`@)&1I<B`]?B!S+UQ1)$-O;F9I9WM?9&5L
M:6U]7$4D+R\["B`@("`@("`@*"@D<')O9VYA;64@/2`B)&1I<B1#;VYF:6=[
M7V1E;&EM?21P<F]G;F%M921#;VYF:6=[7V5X97TB*2P@;&%S="D*("`@("`@
M("`@("`@:68@+7,@(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA;64D0V]N
M9FEG>U]E>&5](CL*("`@("`@("`H*"1P<F]G;F%M92`]("(D9&ER)$-O;F9I
M9WM?9&5L:6U])'!R;V=N86UE(BDL(&QA<W0I"B`@("`@("`@("`@(&EF("US
M("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE(CL*("`@('T*?0H*<W5B
M(%]F:7A?<')O9VYA;64@>PH@("`@)#`@/2`D<')O9VYA;64@?'P]("1%3E9[
M4$%27U!23T=.04U%?3L*("`@(&EF("AI;F1E>"@D<')O9VYA;64L("1#;VYF
M:6=[7V1E;&EM?2D@/"`P*2!["B`@("`@("`@)'!R;V=N86UE(#T@(BXD0V]N
M9FEG>U]D96QI;7TD<')O9VYA;64B.PH@("`@?0H*("`@(",@6%A8("T@:&%C
M:R!T;R!M86ME(%!71"!W;W)K"B`@("!M>2`D<'=D(#T@*&1E9FEN960@)D-W
M9#HZ9V5T8W=D*2`_($-W9#HZ9V5T8W=D*"D*("`@("`@("`@("`@("`@(#H@
M*"AD969I;F5D("97:6XS,CHZ1V5T0W=D*2`_(%=I;C,R.CI'971#=V0H*2`Z
M(&!P=V1@*3L*("`@(&-H;VUP*"1P=V0I.PH@("`@)'!R;V=N86UE(#U^(',O
M7B@_/5PN7"X_7%$D0V]N9FEG>U]D96QI;7U<12DO)'!W9"1#;VYF:6=[7V1E
M;&EM?2\["@H@("`@)$5.5GM005)?4%)/1TY!345](#T@)'!R;V=N86UE.PI]
M"@IS=6(@7W!A<E]I;FET7V5N=B!["B`@("!I9B`H("1%3E9[4$%27TE.251)
M04Q)6D5$?2LK(#T](#$@*2!["B`@("`@("`@<F5T=7)N.PH@("`@?2!E;'-E
M('L*("`@("`@("`D14Y6>U!!4E])3DE424%,25I%1'T@/2`R.PH@("`@?0H*
M("`@(&9O<B`H<7<H(%-005=.140@5$5-4"!#3$5!3B!$14)51R!#04-(12!0
M4D]'3D%-12!!4D=#($%21U9?,"`I("D@>PH@("`@("`@(&1E;&5T92`D14Y6
M>R=005)?)RXD7WT["B`@("!]"B`@("!F;W(@*'%W+R!435!$25(@5$5-4"!#
M3$5!3B!$14)51R`O*2!["B`@("`@("`@)$5.5GLG4$%27R<N)%]](#T@)$5.
M5GLG4$%27T=,3T)!3%\G+B1??2!I9B!E>&ES=',@)$5.5GLG4$%27T=,3T)!
M3%\G+B1??3L*("`@('T*"B`@("!M>2`D<&%R7V-L96%N(#T@(E]?14Y67U!!
M4E]#3$5!3E]?("`@("`@("`@("`@("`@(CL*"B`@("!I9B`H)$5.5GM005)?
M5$5-4'TI('L*("`@("`@("!D96QE=&4@)$5.5GM005)?0TQ%04Y].PH@("`@
M?0H@("`@96QS:68@*"%E>&ES=',@)$5.5GM005)?1TQ/0D%,7T-,14%.?2D@
M>PH@("`@("`@(&UY("1V86QU92`]('-U8G-T<B@D<&%R7V-L96%N+"`Q,B`K
M(&QE;F=T:"@B0TQ%04XB*2D["B`@("`@("`@)$5.5GM005)?0TQ%04Y](#T@
M)#$@:68@)'9A;'5E(#U^("]>4$%27T-,14%./2A<4RLI+SL*("`@('T*?0H*
M<W5B(&]U=',@>PH@("`@<F5T=7)N(&EF("1Q=6EE=#L*("`@(&EF("@D;&]G
M9F@I('L*("`@("`@("!P<FEN="`D;&]G9F@@(D!?7&XB.PH@("`@?0H@("`@
M96QS92!["B`@("`@("`@<')I;G0@(D!?7&XB.PH@("`@?0I]"@IS=6(@:6YI
M=%]I;F,@>PH@("`@<F5Q=6ER92!#;VYF:6<["B`@("!P=7-H($!)3D,L(&=R
M97`@9&5F:6YE9"P@;6%P("1#;VYF:6<Z.D-O;F9I9WLD7WTL('%W*`H@("`@
M("`@(&%R8VAL:6)E>'`@<')I=FQI8F5X<"!S:71E87)C:&5X<"!S:71E;&EB
M97AP"B`@("`@("`@=F5N9&]R87)C:&5X<"!V96YD;W)L:6)E>'`*("`@("D[
M"GT*"B,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C
M(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(PHC(%1H92!M86EN('!A
M8VMA9V4@9F]R('-C<FEP="!E>&5C=71I;VX*"G!A8VMA9V4@;6%I;CL*"G)E
M<75I<F4@4$%2.PIU;G-H:69T($!)3D,L(%PF4$%2.CIF:6YD7W!A<CL*4$%2
M+3YI;7!O<G0H0'!A<E]A<F=S*3L*"F1I92!Q<2AP87(N<&PZ($-A;B=T(&]P
M96X@<&5R;"!S8W)I<'0@(B1P<F]G;F%M92(Z($YO('-U8V@@9FEL92!O<B!D
M:7)E8W1O<GE<;BD*("`@('5N;&5S<R`M92`D<')O9VYA;64["@ID;R`D<')O
M9VYA;64["D-/4D4Z.F5X:70H)#$I(&EF("@D0"`]?B]>7U1+7T58251?7"@H
M7&0K*5PI+RD["F1I92`D0"!I9B`D0#L*"GT["@HD.CI?7T524D]2(#T@)$`@
M:68@)$`["GT*"D-/4D4Z.F5X:70H)#$I(&EF("@D.CI?7T524D]2(#U^+UY?
M5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE("0Z.E]?15)23U(@:68@)#HZ7U]%
M4E)/4CL*"C$["@HC;&EN92`Q,#$Q"@I?7T5.1%]?"@`````!&P,[T````!D`
M``!,<?__[````)Q\__\L`0``7'W__U0!``!L??__;`$``+Q]__^8`0``['__
M_\0!``!,@?__'`(``!R"__]8`@``#(3__YP"```<A?__R`(``%R%___@`@``
MS(7___@"``"\AO__(`,``,R&__\X`P``O(C__WP#``#LB/__D`,``-R)___`
M`P``?(O___`#``#,B___$`0``.R+__\H!```[(S__V@$``!<F/__K`0``-R<
M___P!```7)W__RP%``"\G?__1`4``!0``````````7I2``%\"`$;#`0$B`$`
M`#P````<````6'#__T$+````00X(00X,00X000X40H,%A@2'`X4"1@[L`@,P
M"PX40<,.$$'&#@Q!QPX(0<4.!``D````7````&A[__^^`````$,.0$:#!5:%
M`H<#A@13"@X$Q<?&PT8+%````(0`````?/__$`````!##B!,#@0`*````)P`
M``#X>___1P````!!#@A"A@)!#@Q%#B!$@P-W#@Q!PPX(0<8.!``H````R```
M`!Q\__\B`@```$$."$$.#$,.($>#`X8"`Q,"#@Q!PPX(0<8.!%0```#T````
M('[__UD!````00X(00X,0H<#A0)!#A!!#A1&#J`!1(,%A@1+"@X40<,.$$'&
M#@Q!QPX(0<4.!$$+`OX*#A1!#A##00X,QD$.",=!#@3%1@LX````3`$``"A_
M___!`````$$."$*&`D$.#$*#`T,.('L*#@Q!PPX(0<8.!$(+`G0.#$,.",-!
M#@3&``!`````B`$``+Q____N`0```$$."$$.#$$.$$*&!(<#A0)!#A1%#E!"
M@P4"3PH.%$'##A!!Q@X,0<<."$'%#@1("P```"@```#,`0``:('__PT!````
M1@[`($N'`TF#!4F%`FF&!`**"@X$Q<?&PT(+%````/@!``!,@O__/0````!#
M#B!Y#@0`%````!`"``!T@O__:P````!##C`"9PX$)````"@"``#,@O__X@``
M``!&#L!`3H,$288#5H<"`F(*#@3'QL-#"Q0```!0`@``E(/__PL`````0PX0
M0PX$`$````!H`@``C(/__^<!````00X(00X,00X000X41@[@(%N#!88$AP.%
M`@)*"@X40<,.$$'&#@Q!QPX(0<4.!$$+````$````*P"```XA?__+0``````
M```L````P`(``%2%___L`````$$."$,.($2#`@)("@X(0<,.!$<+8`H."$'#
M#@1'"P`L````\`(``!2&__^?`0```$$."$$.#$,.0`)EA@.'`@+J"@X,0<8.
M"$''#@1""P`<````(`,``(2'__]"`````$,.$$T*#@1("VD.!````!0```!`
M`P``M(?__QX`````0PX@6@X$`#P```!8`P``O(?__P`!````00X(00X,00X0
M00X418,%A@2'`X4"0PYP`H8*#A1!PPX00<8.#$''#@A!Q0X$0@M`````F`,`
M`'R(__]P"P```$$."$$.#$$.$$$.%$8.L(,"`J2#!88$AP.%`@-[`PH.%$'#
M#A!!Q@X,0<<."$'%#@1#"T````#<`P``J)/__WP$````00X(00X,00X000X4
M0PXP1X,%A@2'`X4"`[L""@X40<,.$$'&#@Q!QPX(0<4.!$,+````.````"`$
M``#DE___<P````!!#@A!#@Q##B!$@P.&`@);"@X,0<,."$'&#@1!"T,.#$/#
M#@A!Q@X$````%````%P$```HF/__6P````!##B`"5PX$/````'0$``!PF/__
M(`(```!!#@A"A0(-!5P0`PAU``GP&@GX(A`&"'4`"?`:"?PB`Y<!"L-!QD(-
M!$'%#@1&"P``````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````#_____`````/____\```````````$````!`````0```*T"
M```!````N0(```$```#$`@```0```,X"```!````W`(```$```#I`@```0``
M`#@#```/````N@0```P```#DE`0(#0```'S*!`CU_O]O:($$"`4````TB@0(
M!@```,2"!`@*````<08```L````0````%0`````````#````(#$%"`(```"0
M`@``%````!$````7````5)($"!$````TD@0($@```"`````3````"````/[_
M_V^4D00(____;P(```#P__]OII`$"```````````````````````````````
M```````````````````````````````````````4,`4(```````````JE00(
M.I4$"$J5!`A:E00(:I4$"'J5!`B*E00(FI4$"*J5!`BZE00(RI4$"-J5!`CJ
ME00(^I4$"`J6!`@:E@0(*I8$"#J6!`A*E@0(6I8$"&J6!`AZE@0(BI8$")J6
M!`BJE@0(NI8$",J6!`C:E@0(ZI8$"/J6!`@*EP0(&I<$""J7!`@ZEP0(2I<$
M"%J7!`AJEP0(>I<$"(J7!`B:EP0(JI<$"+J7!`C*EP0(VI<$".J7!`CZEP0(
M"I@$"!J8!`@JF`0(.I@$"$J8!`A:F`0(:I@$"'J8!`B*F`0(FI@$"*J8!`BZ
MF`0(RI@$"-J8!`CJF`0(^I@$"`J9!`@:F00(*ID$"#J9!`A*F00(6ID$"&J9
M!`AZF00(BID$")J9!`BJF00(NID$",J9!`C:F00(ZID$"/J9!`@*F@0(&IH$
M""J:!`@ZF@0(``````````#_____$,X$"*!;``!'0T,Z("A'3E4I(#0N-2XR
M```N<VAS=')T86(`+FEN=&5R<``N;F]T92Y!0DDM=&%G`"YG;G4N:&%S:``N
M9'EN<WEM`"YD>6YS='(`+F=N=2YV97)S:6]N`"YG;G4N=F5R<VEO;E]R`"YR
M96PN9'EN`"YR96PN<&QT`"YI;FET`"YT97AT`"YF:6YI`"YR;V1A=&$`+F5H
M7V9R86UE7VAD<@`N96A?9G)A;64`+F-T;W)S`"YD=&]R<P`N:F-R`"YD>6YA
M;6EC`"YG;W0`+F=O="YP;'0`+F1A=&$`+F)S<P`N8V]M;65N=```````````
M```````````````````````````````````````````````+`````0````(`
M```T@00(-`$``!,```````````````$`````````$P````<````"````2($$
M"$@!```@```````````````$`````````"$```#V__]O`@```&B!!`AH`0``
M7`$```0`````````!`````0````K````"P````(```#$@@0(Q`(``'`'```%
M`````0````0````0````,P````,````"````-(H$"#0*``!Q!@``````````
M```!`````````#L```#___]O`@```*:0!`BF$```[@````0``````````@``
M``(```!(````_O__;P(```"4D00(E!$``*`````%`````@````0`````````
M5P````D````"````-)($"#02```@````!``````````$````"````&`````)
M`````@```%22!`A4$@``D`(```0````+````!`````@```!I`````0````8`
M``#DE`0(Y!0``#````````````````0`````````9`````$````&````%)4$
M"!05```P!0`````````````$````!````&\````!````!@```%":!`A0&@``
M+#``````````````$`````````!U`````0````8```!\R@0(?$H``!P`````
M``````````0`````````>P````$````"````H,H$"*!*```A7P``````````
M```@`````````(,````!`````@```,0I!0C$J0``U```````````````!```
M``````"1`````0````(```"8*@4(F*H``+0$``````````````0`````````
MFP````$````#`````#`%"`"P```(```````````````$`````````*(````!
M`````P````@P!0@(L```"```````````````!`````````"I`````0````,`
M```0,`4($+````0```````````````0`````````K@````8````#````%#`%
M"!2P```(`0``!0`````````$````"````+<````!`````P```!PQ!0@<L0``
M!```````````````!`````0```"\`````0````,````@,04((+$``%0!````
M``````````0````$````Q0````$````#````=#(%"'2R```4````````````
M```$`````````,L````(`````P```*`R!0B(L@``8!``````````````(```
M``````#0`````0```#``````````B+(``!$```````````````$````!````
H`0````,``````````````)FR``#9```````````````!````````````
